/**************************************************
 *
 * I/O definitions for the M16C/62P derivative.
 *
 * Copyright 2003 IAR Systems. All rights reserved.
 *
 * $Revision: 1.9 
 **************************************************/

#ifndef __IOM16C62P_H__
#define __IOM16C62P_H__


#ifdef __IAR_SYSTEMS_ICC__
#pragma language=extended

/*-------------------------------------------------------------------------
 *   Processor Registers
 *-------------------------------------------------------------------------*/

 __no_init volatile unsigned short PM @ 0x004;   /* Processor Mode Register */ 
  
 
/* Processor Mode Register 0 */ 
__no_init volatile union
{
  unsigned char PM0;
  struct
  {
    unsigned char PM00           : 1;  
    unsigned char PM01           : 1;  
    unsigned char PM02           : 1;  
    unsigned char PM03           : 1;  
    unsigned char PM04           : 1;  
    unsigned char PM05           : 1;  
    unsigned char PM06           : 1;  
    unsigned char PM07           : 1;  
  } PM0_bit;
} @ 0x004;
  
 
/* Processor Mode Register 1 */ 
__no_init volatile union
{
  unsigned char PM1;
  struct
  {
    unsigned char PM10           : 1;  
    unsigned char PM11           : 1;  
    unsigned char PM12           : 1;  
    unsigned char PM13           : 1;  
    unsigned char PM14           : 1;  
    unsigned char PM15           : 1;  
    unsigned char                : 1;  
    unsigned char PM17           : 1;  
  } PM1_bit;
} @ 0x005;
  
 
/* System clock control register 0 */ 
__no_init volatile union
{
  unsigned char CM0;
  struct
  {
    unsigned char CM00           : 1;  
    unsigned char CM01           : 1;  
    unsigned char CM02           : 1;  
    unsigned char CM03           : 1;  
    unsigned char CM04           : 1;  
    unsigned char CM05           : 1;  
    unsigned char CM06           : 1;  
    unsigned char CM07           : 1;  
  } CM0_bit;
} @ 0x006;
  
 
/* System clock control register 1 */ 
__no_init volatile union
{
  unsigned char CM1;
  struct
  {
    unsigned char CM10           : 1;  
    unsigned char CM11           : 1;  
    unsigned char                : 1;  
    unsigned char                : 1;  
    unsigned char                : 1;  
    unsigned char CM15           : 1;  
    unsigned char CM16           : 1;  
    unsigned char CM17           : 1;  
  } CM1_bit;
} @ 0x007;
  
 __no_init volatile unsigned short CM @ 0x006;   /* System clock control register */ 
  
 
/* Chip select control register */ 
__no_init volatile union
{
  unsigned char CSR;
  struct
  {
    unsigned char CS0            : 1;  
    unsigned char CS1            : 1;  
    unsigned char CS2            : 1;  
    unsigned char CS3            : 1;  
    unsigned char CS0W           : 1;  
    unsigned char CS1W           : 1;  
    unsigned char CS2W           : 1;  
    unsigned char CS3W           : 1;  
  } CSR_bit;
} @ 0x008;
  
 
/* Protect register */ 
__no_init volatile union
{
  unsigned char PRCR;
  struct
  {
    unsigned char PRC0           : 1;  
    unsigned char PRC1           : 1;  
    unsigned char PRC2           : 1;  
    unsigned char PRC3           : 1;  
  } PRCR_bit;
} @ 0x00A;
  
 
/* Oscillation stop detection register */ 
__no_init volatile union
{
  unsigned char CM2;
  struct
  {
    unsigned char CM20           : 1;  
    unsigned char CM21           : 1;  
    unsigned char CM22           : 1;  
    unsigned char CM23           : 1;  
    unsigned char                : 1;  
    unsigned char                : 1;  
    unsigned char                : 1;  
    unsigned char CM27           : 1;  
  } CM2_bit;
} @ 0x00C;
  
 __no_init volatile unsigned char CSE @ 0x01B;   /* Chip select expansion control register */ 
  
 
/* PLC control register 0 */ 
__no_init volatile union
{
  unsigned char PLC0;
  struct
  {
    unsigned char PLC00          : 1;  
    unsigned char PLC01          : 1;  
    unsigned char PLC02          : 1;  
    unsigned char                : 4;  
    unsigned char PLC07          : 1;  
  } PLC0_bit;
} @ 0x01C;
  
 
/* Processor Mode Register 2 */ 
__no_init volatile union
{
  unsigned char PM2;
  struct
  {
    unsigned char PM20           : 1;  
    unsigned char PM21           : 1;  
    unsigned char PM22           : 1;  
  } PM2_bit;
} @ 0x01E;
  
 __no_init volatile unsigned char PCLKR @ 0x25E;   /* Peripheral clock select register */ 
  
 

/*-------------------------------------------------------------------------
 *   Watchdog Timer
 *-------------------------------------------------------------------------*/

 __no_init volatile unsigned char WDTS @ 0x00E;   /* Watchdog timer start register */ 
  
 __no_init volatile unsigned char WDC @ 0x00F;   /* Watchdog timer control register */ 
  
 

/*-------------------------------------------------------------------------
 *   Interrupt Control Register
 *-------------------------------------------------------------------------*/

 __no_init volatile unsigned char AIER @ 0x009;   /* Address match interrupt enable */ 
  
 __no_init volatile unsigned char RMAD00 @ 0x010;   /* Address match interrupt register 0 (low) */ 
  
 __no_init volatile unsigned char RMAD01 @ 0x011;   /* Address match interrupt register 0 (mid) */ 
  
 __no_init volatile unsigned char RMAD02 @ 0x012;   /* Address match interrupt register 0 (high) */ 
  
 __no_init volatile unsigned char RMAD10 @ 0x014;   /* Address match interrupt register 1 (low) */ 
  
 __no_init volatile unsigned char RMAD11 @ 0x015;   /* Address match interrupt register 1 (mid) */ 
  
 __no_init volatile unsigned char RMAD12 @ 0x016;   /* Address match interrupt register 1 (high) */ 
  
 
/* INT3 interrupt control register */ 
__no_init volatile union
{
  unsigned char INT3IC;
  struct
  {
    unsigned char ILVL           : 3;  
    unsigned char IR             : 1;  
    unsigned char POL            : 1;  
  } INT3IC_bit;
} @ 0x044;
  
 
/* Timer B5 interrupt control register */ 
__no_init volatile union
{
  unsigned char TB5IC;
  struct
  {
    unsigned char ILVL           : 3;  
    unsigned char IR             : 1;  
  } TB5IC_bit;
} @ 0x045;
  
 
/* UART0 BUS collision detection interrupt control register */ 
__no_init volatile union
{
  unsigned char U0BCNIC;
  struct
  {
    unsigned char ILVL           : 3;  
    unsigned char IR             : 1;  
  } U0BCNIC_bit;
} @ 0x046;
  
 
/* Timer B4 interrupt control register */ 
__no_init volatile union
{
  unsigned char TB4IC;
  struct
  {
    unsigned char ILVL           : 3;  
    unsigned char IR             : 1;  
  } TB4IC_bit;
} @ 0x046;
  
 
/* UART1 BUS collision detection interrupt control register */ 
__no_init volatile union
{
  unsigned char U1BCNIC;
  struct
  {
    unsigned char ILVL           : 3;  
    unsigned char IR             : 1;  
  } U1BCNIC_bit;
} @ 0x047;
  
 
/* Timer B3 interrupt control register */ 
__no_init volatile union
{
  unsigned char TB3IC;
  struct
  {
    unsigned char ILVL           : 3;  
    unsigned char IR             : 1;  
  } TB3IC_bit;
} @ 0x047;
  
 
/* SI/O4 interrupt control register */ 
__no_init volatile union
{
  unsigned char S4IC;
  struct
  {
    unsigned char ILVL           : 3;  
    unsigned char IR             : 1;  
  } S4IC_bit;
} @ 0x048;
  
 
/* INT5 interrupt control register */ 
__no_init volatile union
{
  unsigned char INT5IC;
  struct
  {
    unsigned char ILVL           : 3;  
    unsigned char IR             : 1;  
    unsigned char POL            : 1;  
  } INT5IC_bit;
} @ 0x048;
  
 
/* SI/O3 interrupt control register */ 
__no_init volatile union
{
  unsigned char S3IC;
  struct
  {
    unsigned char ILVL           : 3;  
    unsigned char IR             : 1;  
  } S3IC_bit;
} @ 0x049;
  
 
/* INT4 interrupt control register */ 
__no_init volatile union
{
  unsigned char INT4IC;
  struct
  {
    unsigned char ILVL           : 3;  
    unsigned char IR             : 1;  
    unsigned char POL            : 1;  
  } INT4IC_bit;
} @ 0x049;
  
 
/* UART2 Bus collision detection interrupt control register */ 
__no_init volatile union
{
  unsigned char BCNIC;
  struct
  {
    unsigned char ILVL           : 3;  
    unsigned char IR             : 1;  
  } BCNIC_bit;
} @ 0x04A;
  
 
/* DMA0 interrupt control register */ 
__no_init volatile union
{
  unsigned char DMA0IC;
  struct
  {
    unsigned char ILVL           : 3;  
    unsigned char IR             : 1;  
  } DMA0IC_bit;
} @ 0x04B;
  
 
/* DMA1 interrupt control register */ 
__no_init volatile union
{
  unsigned char DMA1IC;
  struct
  {
    unsigned char ILVL           : 3;  
    unsigned char IR             : 1;  
  } DMA1IC_bit;
} @ 0x04C;
  
 
/* Key input interrupt control register */ 
__no_init volatile union
{
  unsigned char KUPIC;
  struct
  {
    unsigned char ILVL           : 3;  
    unsigned char IR             : 1;  
  } KUPIC_bit;
} @ 0x04D;
  
 
/* AD conversion interrupt control register */ 
__no_init volatile union
{
  unsigned char ADIC;
  struct
  {
    unsigned char ILVL           : 3;  
    unsigned char IR             : 1;  
  } ADIC_bit;
} @ 0x04E;
  
 
/* UART2 transmit interrupt control register */ 
__no_init volatile union
{
  unsigned char S2TIC;
  struct
  {
    unsigned char ILVL           : 3;  
    unsigned char IR             : 1;  
  } S2TIC_bit;
} @ 0x04F;
  
 
/* UART2 receive interrupt control register */ 
__no_init volatile union
{
  unsigned char S2RIC;
  struct
  {
    unsigned char ILVL           : 3;  
    unsigned char IR             : 1;  
  } S2RIC_bit;
} @ 0x050;
  
 
/* UART0 transmit interrupt control register */ 
__no_init volatile union
{
  unsigned char S0TIC;
  struct
  {
    unsigned char ILVL           : 3;  
    unsigned char IR             : 1;  
  } S0TIC_bit;
} @ 0x051;
  
 
/* UART0 receive interrupt control register */ 
__no_init volatile union
{
  unsigned char S0RIC;
  struct
  {
    unsigned char ILVL           : 3;  
    unsigned char IR             : 1;  
  } S0RIC_bit;
} @ 0x052;
  
 
/* UART1 transmit interrupt control register */ 
__no_init volatile union
{
  unsigned char S1TIC;
  struct
  {
    unsigned char ILVL           : 3;  
    unsigned char IR             : 1;  
  } S1TIC_bit;
} @ 0x053;
  
 
/* UART1 receive interrupt control register */ 
__no_init volatile union
{
  unsigned char S1RIC;
  struct
  {
    unsigned char ILVL           : 3;  
    unsigned char IR             : 1;  
  } S1RIC_bit;
} @ 0x054;
  
 
/* Timer A0 interrupt control register */ 
__no_init volatile union
{
  unsigned char TA0IC;
  struct
  {
    unsigned char ILVL           : 3;  
    unsigned char IR             : 1;  
  } TA0IC_bit;
} @ 0x055;
  
 
/* Timer A1 interrupt control register */ 
__no_init volatile union
{
  unsigned char TA1IC;
  struct
  {
    unsigned char ILVL           : 3;  
    unsigned char IR             : 1;  
  } TA1IC_bit;
} @ 0x056;
  
 
/* Timer A2 interrupt control register */ 
__no_init volatile union
{
  unsigned char TA2IC;
  struct
  {
    unsigned char ILVL           : 3;  
    unsigned char IR             : 1;  
  } TA2IC_bit;
} @ 0x057;
  
 
/* Timer A3 interrupt control register */ 
__no_init volatile union
{
  unsigned char TA3IC;
  struct
  {
    unsigned char ILVL           : 3;  
    unsigned char IR             : 1;  
  } TA3IC_bit;
} @ 0x058;
  
 
/* Timer A4 interrupt control register */ 
__no_init volatile union
{
  unsigned char TA4IC;
  struct
  {
    unsigned char ILVL           : 3;  
    unsigned char IR             : 1;  
  } TA4IC_bit;
} @ 0x059;
  
 
/* Timer B0 interrupt control register */ 
__no_init volatile union
{
  unsigned char TB0IC;
  struct
  {
    unsigned char ILVL           : 3;  
    unsigned char IR             : 1;  
  } TB0IC_bit;
} @ 0x05A;
  
 
/* Timer B1 interrupt control register */ 
__no_init volatile union
{
  unsigned char TB1IC;
  struct
  {
    unsigned char ILVL           : 3;  
    unsigned char IR             : 1;  
  } TB1IC_bit;
} @ 0x05B;
  
 
/* Timer B2 interrupt control register */ 
__no_init volatile union
{
  unsigned char TB2IC;
  struct
  {
    unsigned char ILVL           : 3;  
    unsigned char IR             : 1;  
  } TB2IC_bit;
} @ 0x05C;
  
 
/* Interrupt 0 interrupt control register */ 
__no_init volatile union
{
  unsigned char INT0IC;
  struct
  {
    unsigned char ILVL           : 3;  
    unsigned char IR             : 1;  
    unsigned char POL            : 1;  
  } INT0IC_bit;
} @ 0x05D;
  
 
/* Interrupt 1 interrupt control register */ 
__no_init volatile union
{
  unsigned char INT1IC;
  struct
  {
    unsigned char ILVL           : 3;  
    unsigned char IR             : 1;  
    unsigned char POL            : 1;  
  } INT1IC_bit;
} @ 0x05E;
  
 
/* Interrupt 2 interrupt control register */ 
__no_init volatile union
{
  unsigned char INT2IC;
  struct
  {
    unsigned char ILVL           : 3;  
    unsigned char IR             : 1;  
    unsigned char POL            : 1;  
  } INT2IC_bit;
} @ 0x05F;
  
 __no_init volatile unsigned char RMAD20 @ 0x1B8;   /* Address match interrupt register 2 (low) */ 
  
 __no_init volatile unsigned char RMAD21 @ 0x1B9;   /* Address match interrupt register 2 (mid) */ 
  
 __no_init volatile unsigned char RMAD22 @ 0x1BA;   /* Address match interrupt register 2 (high) */ 
  
 __no_init volatile unsigned char AIER2 @ 0x1BB;   /* Address match interrupt enable register 2 */ 
  
 __no_init volatile unsigned char RMAD30 @ 0x1BC;   /* Address match interrupt register 2 (low) */ 
  
 __no_init volatile unsigned char RMAD31 @ 0x1BD;   /* Address match interrupt register 2 (mid) */ 
  
 __no_init volatile unsigned char RMAD32 @ 0x1BE;   /* Address match interrupt register 2 (high) */ 
  
 __no_init volatile unsigned char IFSR2A @ 0x35E;   /* Interrupt cause select register 2 */ 
  
 __no_init volatile unsigned char IFSR @ 0x35F;   /* Interrupt cause select register */ 
  
 

/*-------------------------------------------------------------------------
 *   DMA Registers
 *-------------------------------------------------------------------------*/

 __no_init volatile unsigned char SAR00 @ 0x020;   /* DMA0 source pointer (low) */ 
  
 __no_init volatile unsigned char SAR01 @ 0x021;   /* DMA0 source pointer (mid) */ 
  
 __no_init volatile unsigned char SAR02 @ 0x022;   /* DMA0 source pointer (high) */ 
  
 __no_init volatile unsigned char DAR00 @ 0x024;   /* DMA0 destination pointer (low) */ 
  
 __no_init volatile unsigned char DAR01 @ 0x025;   /* DMA0 destination pointer (mid) */ 
  
 __no_init volatile unsigned char DAR02 @ 0x026;   /* DMA0 destination pointer (high) */ 
  
 __no_init volatile unsigned short TCR0 @ 0x028;   /* DMA0 transfer counter */ 
  
 __no_init volatile unsigned char TCR00 @ 0x028;   /* DMA0 transfer counter (low) */ 
  
 __no_init volatile unsigned char TCR01 @ 0x029;   /* DMA0 transfer counter (high) */ 
  
 
/* DMA0 control register */ 
__no_init volatile union
{
  unsigned char DM0CON;
  struct
  {
    unsigned char DMBIT_DM0CON   : 1;  
    unsigned char DMASL_DM0CON   : 1;  
    unsigned char DMAS_DM0CON    : 1;  
    unsigned char DMAE_DM0CON    : 1;  
    unsigned char DSD_DM0CON     : 1;  
    unsigned char DAD_DM0CON     : 1;  
  } DM0CON_bit;
} @ 0x02C;
  
 __no_init volatile unsigned char SAR10 @ 0x030;   /* DMA1 source pointer (low) */ 
  
 __no_init volatile unsigned char SAR11 @ 0x031;   /* DMA1 source pointer (mid) */ 
  
 __no_init volatile unsigned char SAR12 @ 0x032;   /* DMA1 source pointer (high) */ 
  
 __no_init volatile unsigned char DAR10 @ 0x034;   /* DMA1 destination pointer (low) */ 
  
 __no_init volatile unsigned char DAR11 @ 0x035;   /* DMA1 destination pointer (mid) */ 
  
 __no_init volatile unsigned char DAR12 @ 0x036;   /* DMA1 destination pointer (high) */ 
  
 __no_init volatile unsigned short TCR1 @ 0x038;   /* DMA1 transfer counter */ 
  
 __no_init volatile unsigned char TCR10 @ 0x038;   /* DMA1 transfer counter (low) */ 
  
 __no_init volatile unsigned char TCR11 @ 0x039;   /* DMA1 transfer counter (high) */ 
  
 
/* DMA1 control register */ 
__no_init volatile union
{
  unsigned char DM1CON;
  struct
  {
    unsigned char DMBIT_DM1CON   : 1;  
    unsigned char DMASL_DM1CON   : 1;  
    unsigned char DMAS_DM1CON    : 1;  
    unsigned char DMAE_DM1CON    : 1;  
    unsigned char DSD_DM1CON     : 1;  
    unsigned char DAD_DM1CON     : 1;  
  } DM1CON_bit;
} @ 0x03C;
  
 __no_init volatile unsigned char DM0SL @ 0x3B8;   /* DMA0 cause selection */ 
  
 __no_init volatile unsigned char DM1SL @ 0x3BA;   /* DMA1 cause selection */ 
  
 

/*-------------------------------------------------------------------------
 *   Timer Registers
 *-------------------------------------------------------------------------*/

 
/* Timer A/B count start flags */ 
__no_init volatile union
{
  unsigned char TABSR;
  struct
  {
    unsigned char TA0S           : 1;  
    unsigned char TA1S           : 1;  
    unsigned char TA2S           : 1;  
    unsigned char TA3S           : 1;  
    unsigned char TA4S           : 1;  
    unsigned char TB0S           : 1;  
    unsigned char TB1S           : 1;  
    unsigned char TB2S           : 1;  
  } TABSR_bit;
} @ 0x380;
  
 
/* Clock prescaler reset flag */ 
__no_init volatile union
{
  unsigned char CPSRF;
  struct
  {
    unsigned char                : 7;  
    unsigned char CPSR           : 1;  
  } CPSRF_bit;
} @ 0x381;
  
 
/* One-shot start flagl */ 
__no_init volatile union
{
  unsigned char ONSF;
  struct
  {
    unsigned char TA0OS          : 1;  
    unsigned char TA1OS          : 1;  
    unsigned char TA2OS          : 1;  
    unsigned char TA3OS          : 1;  
    unsigned char TA4OS          : 1;  
    unsigned char ZIE            : 1;  
    unsigned char TA0TGL         : 1;  
    unsigned char TA0TGH         : 1;  
  } ONSF_bit;
} @ 0x382;
  
 
/* Trigger select register */ 
__no_init volatile union
{
  unsigned char TRGSR;
  struct
  {
    unsigned char TA1TGL         : 1;  
    unsigned char TA1TGH         : 1;  
    unsigned char TA2TGL         : 1;  
    unsigned char TA2TGH         : 1;  
    unsigned char TA3TGL         : 1;  
    unsigned char TA3TGH         : 1;  
    unsigned char TA4TGL         : 1;  
    unsigned char TA4TGH         : 1;  
  } TRGSR_bit;
} @ 0x383;
  
 
/* Up- down-count selection flag */ 
__no_init volatile union
{
  unsigned char UDF;
  struct
  {
    unsigned char TA0UD          : 1;  
    unsigned char TA1UD          : 1;  
    unsigned char TA2UD          : 1;  
    unsigned char TA3UD          : 1;  
    unsigned char TA4UD          : 1;  
    unsigned char TA2P           : 1;  
    unsigned char TA3P           : 1;  
    unsigned char TA4P           : 1;  
  } UDF_bit;
} @ 0x384;
  
 __no_init volatile unsigned short TA0 @ 0x386;   /* Timer A0 */ 
  
 __no_init volatile unsigned char TA0L @ 0x386;   /* Timer A0 (low byte) */ 
  
 __no_init volatile unsigned char TA0H @ 0x387;   /* Timer A0 (high byte) */ 
  
 __no_init volatile unsigned short TA1 @ 0x388;   /* Timer A1 */ 
  
 __no_init volatile unsigned char TA1L @ 0x388;   /* Timer A1 (low byte) */ 
  
 __no_init volatile unsigned char TA1H @ 0x389;   /* Timer A1 (high byte) */ 
  
 __no_init volatile unsigned short TA2 @ 0x38A;   /* Timer A2 */ 
  
 __no_init volatile unsigned char TA2L @ 0x38A;   /* Timer A2 (low byte) */ 
  
 __no_init volatile unsigned char TA2H @ 0x38B;   /* Timer A2 (high byte) */ 
  
 __no_init volatile unsigned short TA3 @ 0x38C;   /* Timer A3 */ 
  
 __no_init volatile unsigned char TA3L @ 0x38C;   /* Timer A3 (low byte) */ 
  
 __no_init volatile unsigned char TA3H @ 0x38D;   /* Timer A3 (high byte) */ 
  
 __no_init volatile unsigned short TA4 @ 0x38E;   /* Timer A4 */ 
  
 __no_init volatile unsigned char TA4L @ 0x38E;   /* Timer A4 (low byte) */ 
  
 __no_init volatile unsigned char TA4H @ 0x38F;   /* Timer A4 (high byte) */ 
  
 __no_init volatile unsigned short TB0 @ 0x390;   /* Timer B0 */ 
  
 __no_init volatile unsigned char TB0L @ 0x390;   /* Timer B0 (low byte) */ 
  
 __no_init volatile unsigned char TB0H @ 0x391;   /* Timer B0 (high byte) */ 
  
 __no_init volatile unsigned short TB1 @ 0x392;   /* Timer B1 */ 
  
 __no_init volatile unsigned char TB1L @ 0x392;   /* Timer B1 (low byte) */ 
  
 __no_init volatile unsigned char TB1H @ 0x393;   /* Timer B1 (high byte) */ 
  
 __no_init volatile unsigned short TB2 @ 0x394;   /* Timer B2 */ 
  
 __no_init volatile unsigned char TB2L @ 0x394;   /* Timer B2 (low byte) */ 
  
 __no_init volatile unsigned char TB2H @ 0x395;   /* Timer B2 (high byte) */ 
  
 
/* Timer A0 mode register */ 
__no_init volatile union
{
  unsigned char TA0MR;
  struct
  {
    unsigned char TMOD0_TA0MR    : 1;  
    unsigned char TMOD1_TA0MR    : 1;  
    unsigned char MR0_TA0MR      : 1;  
    unsigned char MR1_TA0MR      : 1;  
    unsigned char MR2_TA0MR      : 1;  
    unsigned char MR3_TA0MR      : 1;  
    unsigned char TCK0_TA0MR     : 1;  
    unsigned char TCK1_TA0MR     : 1;  
  } TA0MR_bit;
} @ 0x396;
  
 
/* Timer A1 mode register */ 
__no_init volatile union
{
  unsigned char TA1MR;
  struct
  {
    unsigned char TMOD0_TA1MR    : 1;  
    unsigned char TMOD1_TA1MR    : 1;  
    unsigned char MR0_TA1MR      : 1;  
    unsigned char MR1_TA1MR      : 1;  
    unsigned char MR2_TA1MR      : 1;  
    unsigned char MR3_TA1MR      : 1;  
    unsigned char TCK0_TA1MR     : 1;  
    unsigned char TCK1_TA1MR     : 1;  
  } TA1MR_bit;
} @ 0x397;
  
 
/* Timer A2 mode register */ 
__no_init volatile union
{
  unsigned char TA2MR;
  struct
  {
    unsigned char TMOD0_TA2MR    : 1;  
    unsigned char TMOD1_TA2MR    : 1;  
    unsigned char MR0_TA2MR      : 1;  
    unsigned char MR1_TA2MR      : 1;  
    unsigned char MR2_TA2MR      : 1;  
    unsigned char MR3_TA2MR      : 1;  
    unsigned char TCK0_TA2MR     : 1;  
    unsigned char TCK1_TA2MR     : 1;  
  } TA2MR_bit;
} @ 0x398;
  
 
/* Timer A3 mode register */ 
__no_init volatile union
{
  unsigned char TA3MR;
  struct
  {
    unsigned char TMOD0_TA3MR    : 1;  
    unsigned char TMOD1_TA3MR    : 1;  
    unsigned char MR0_TA3MR      : 1;  
    unsigned char MR1_TA3MR      : 1;  
    unsigned char MR2_TA3MR      : 1;  
    unsigned char MR3_TA3MR      : 1;  
    unsigned char TCK0_TA3MR     : 1;  
    unsigned char TCK1_TA3MR     : 1;  
  } TA3MR_bit;
} @ 0x399;
  
 
/* Timer A4 mode register */ 
__no_init volatile union
{
  unsigned char TA4MR;
  struct
  {
    unsigned char TMOD0_TA4MR    : 1;  
    unsigned char TMOD1_TA4MR    : 1;  
    unsigned char MR0_TA4MR      : 1;  
    unsigned char MR1_TA4MR      : 1;  
    unsigned char MR2_TA4MR      : 1;  
    unsigned char MR3_TA4MR      : 1;  
    unsigned char TCK0_TA4MR     : 1;  
    unsigned char TCK1_TA4MR     : 1;  
  } TA4MR_bit;
} @ 0x39A;
  
 
/* Timer B0 mode register */ 
__no_init volatile union
{
  unsigned char TB0MR;
  struct
  {
    unsigned char TMOD0_TB0MR    : 1;  
    unsigned char TMOD1_TB0MR    : 1;  
    unsigned char MR0_TB0MR      : 1;  
    unsigned char MR1_TB0MR      : 1;  
    unsigned char MR2_TB0MR      : 1;  
    unsigned char MR3_TB0MR      : 1;  
    unsigned char TCK0_TB0MR     : 1;  
    unsigned char TCK1_TB0MR     : 1;  
  } TB0MR_bit;
} @ 0x39B;
  
 
/* Timer B1 mode register */ 
__no_init volatile union
{
  unsigned char TB1MR;
  struct
  {
    unsigned char TMOD0_TB1MR    : 1;  
    unsigned char TMOD1_TB1MR    : 1;  
    unsigned char MR0_TB1MR      : 1;  
    unsigned char MR1_TB1MR      : 1;  
    unsigned char                : 1;  
    unsigned char MR3_TB1MR      : 1;  
    unsigned char TCK0_TB1MR     : 1;  
    unsigned char TCK1_TB1MR     : 1;  
  } TB1MR_bit;
} @ 0x39C;
  
 
/* Timer B2 mode register */ 
__no_init volatile union
{
  unsigned char TB2MR;
  struct
  {
    unsigned char TMOD0_TB2MR    : 1;  
    unsigned char TMOD1_TB2MR    : 1;  
    unsigned char MR0_TB2MR      : 1;  
    unsigned char MR1_TB2MR      : 1;  
    unsigned char                : 1;  
    unsigned char MR3_TB2MR      : 1;  
    unsigned char TCK0_TB2MR     : 1;  
    unsigned char TCK1_TB2MR     : 1;  
  } TB2MR_bit;
} @ 0x39D;
  
 
/* Timer B2 special mode register */ 
__no_init volatile union
{
  unsigned char TB2SC;
  struct
  {
    unsigned char PWCON          : 1;  
    unsigned char IVPCR1         : 1;  
  } TB2SC_bit;
} @ 0x39E;
  
 
/* Timer B3,4,5 count start flag */ 
__no_init volatile union
{
  unsigned char TBSR;
  struct
  {
    unsigned char                : 5;  
    unsigned char TB3S           : 1;  
    unsigned char TB4S           : 1;  
    unsigned char TB5S           : 1;  
  } TBSR_bit;
} @ 0x340;
  
 __no_init volatile unsigned short TB3 @ 0x350;   /* Timer B3 */ 
  
 __no_init volatile unsigned char TB3L @ 0x350;   /* Timer B3 (low byte) */ 
  
 __no_init volatile unsigned char TB3H @ 0x351;   /* Timer B3 (high byte) */ 
  
 __no_init volatile unsigned short TB4 @ 0x352;   /* Timer B4 */ 
  
 __no_init volatile unsigned char TB4L @ 0x352;   /* Timer B4 (low byte) */ 
  
 __no_init volatile unsigned char TB4H @ 0x353;   /* Timer B4 (high byte) */ 
  
 __no_init volatile unsigned short TB5 @ 0x354;   /* Timer B5 */ 
  
 __no_init volatile unsigned char TB5L @ 0x354;   /* Timer B5 (low byte) */ 
  
 __no_init volatile unsigned char TB5H @ 0x355;   /* Timer B5 (high byte) */ 
  
 
/* Timer B3 mode register */ 
__no_init volatile union
{
  unsigned char TB3MR;
  struct
  {
    unsigned char TMOD0_TB3MR    : 1;  
    unsigned char TMOD1_TB3MR    : 1;  
    unsigned char MR0_TB3MR      : 1;  
    unsigned char MR1_TB3MR      : 1;  
    unsigned char MR2_TB3MR      : 1;  
    unsigned char MR3_TB3MR      : 1;  
    unsigned char TCK0_TB3MR     : 1;  
    unsigned char TCK1_TB3MR     : 1;  
  } TB3MR_bit;
} @ 0x35B;
  
 
/* Timer B4 mode register */ 
__no_init volatile union
{
  unsigned char TB4MR;
  struct
  {
    unsigned char TMOD0_TB4MR    : 1;  
    unsigned char TMOD1_TB4MR    : 1;  
    unsigned char MR0_TB4MR      : 1;  
    unsigned char MR1_TB4MR      : 1;  
    unsigned char                : 1;  
    unsigned char MR3_TB4MR      : 1;  
    unsigned char TCK0_TB4MR     : 1;  
    unsigned char TCK1_TB4MR     : 1;  
  } TB4MR_bit;
} @ 0x35C;
  
 
/* Timer B5 mode register */ 
__no_init volatile union
{
  unsigned char TB5MR;
  struct
  {
    unsigned char TMOD0_TB5MR    : 1;  
    unsigned char TMOD1_TB5MR    : 1;  
    unsigned char MR0_TB5MR      : 1;  
    unsigned char MR1_TB5MR      : 1;  
    unsigned char                : 1;  
    unsigned char MR3_TB5MR      : 1;  
    unsigned char TCK0_TB5MR     : 1;  
    unsigned char TCK1_TB5MR     : 1;  
  } TB5MR_bit;
} @ 0x35D;
  
 __no_init volatile unsigned short TA11 @ 0x342;   /* Timer A1-1 register */ 
  
 __no_init volatile unsigned char TA11L @ 0x342;   /* Timer A1-1 register (low byte) */ 
  
 __no_init volatile unsigned char TA11H @ 0x343;   /* Timer A1-1 register (high byte) */ 
  
 __no_init volatile unsigned short TA21 @ 0x344;   /* Timer A2-1 register */ 
  
 __no_init volatile unsigned char TA21L @ 0x344;   /* Timer A2-1 register (low byte) */ 
  
 __no_init volatile unsigned char TA21H @ 0x345;   /* Timer A2-1 register (high byte) */ 
  
 __no_init volatile unsigned short TA41 @ 0x346;   /* Timer A4-1 register */ 
  
 __no_init volatile unsigned char TA41L @ 0x346;   /* Timer A4-1 register (low byte) */ 
  
 __no_init volatile unsigned char TA41H @ 0x347;   /* Timer A4-1 register (high byte) */ 
  
 
/* Three-phase PWM control register 0 */ 
__no_init volatile union
{
  unsigned char INVC0;
  struct
  {
    unsigned char INV00          : 1;  
    unsigned char INV01          : 1;  
    unsigned char INV02          : 1;  
    unsigned char INV03          : 1;  
    unsigned char INV04          : 1;  
    unsigned char INV05          : 1;  
    unsigned char INV06          : 1;  
    unsigned char INV07          : 1;  
  } INVC0_bit;
} @ 0x348;
  
 
/* Three-phase PWM control register 1 */ 
__no_init volatile union
{
  unsigned char INVC1;
  struct
  {
    unsigned char INV10          : 1;  
    unsigned char INV11          : 1;  
    unsigned char INV12          : 1;  
    unsigned char INV13          : 1;  
    unsigned char INV14          : 1;  
    unsigned char INV15          : 1;  
    unsigned char INV16          : 1;  
    unsigned char                : 1;  
  } INVC1_bit;
} @ 0x349;
  
 
/* Three-phase output buffer register 0 */ 
__no_init volatile union
{
  unsigned char IDB0;
  struct
  {
    unsigned char DU0            : 1;  
    unsigned char DUB0           : 1;  
    unsigned char DV0            : 1;  
    unsigned char DVB0           : 1;  
    unsigned char DW0            : 1;  
    unsigned char DWB0           : 1;  
    unsigned char                : 2;  
  } IDB0_bit;
} @ 0x34A;
  
 
/* Three-phase output buffer register 1 */ 
__no_init volatile union
{
  unsigned char IDB1;
  struct
  {
    unsigned char DU1            : 1;  
    unsigned char DUB1           : 1;  
    unsigned char DV1            : 1;  
    unsigned char DVB1           : 1;  
    unsigned char DW1            : 1;  
    unsigned char DWB1           : 1;  
    unsigned char                : 2;  
  } IDB1_bit;
} @ 0x34B;
  
 __no_init volatile unsigned char DTT @ 0x34C;   /* Dead time timer */ 
  
 __no_init volatile unsigned char ICTB2 @ 0x34D;   /* Timer B2 interrupt occurence frequency set coutnter */ 
  
 

/*-------------------------------------------------------------------------
 *   UART Registers
 *-------------------------------------------------------------------------*/

 
/* UART 0 transmit/receive mode register */ 
__no_init volatile union
{
  unsigned char U0MR;
  struct
  {
    unsigned char SMD0_U0MR      : 1;  
    unsigned char SMD1_U0MR      : 1;  
    unsigned char SMD2_U0MR      : 1;  
    unsigned char CKDIR_U0MR     : 1;  
    unsigned char STPS_U0MR      : 1;  
    unsigned char PRY_U0MR       : 1;  
    unsigned char PRYE_U0MR      : 1;  
    unsigned char IOPOL_U0MR     : 1;  
  } U0MR_bit;
} @ 0x3A0;
  
 __no_init volatile unsigned char U0BRG @ 0x3A1;   /* UART 0 baud rate generator */ 
  
 __no_init volatile unsigned short U0TB @ 0x3A2;   /* UART 0 transmit buffer */ 
  
 __no_init volatile unsigned char U0TBL @ 0x3A2;   /* UART 0 transmit buffer (low byte) */ 
  
 __no_init volatile unsigned char U0TBH @ 0x3A3;   /* UART 0 transmit buffer (high byte) */ 
  
 __no_init volatile unsigned short U0C @ 0x3A4;   /* UART 0 transmit/receive control register */ 
  
 
/* UART 0 transmit/receive control register 0 */ 
__no_init volatile union
{
  unsigned char U0C0;
  struct
  {
    unsigned char CLK0_U0C0      : 1;  
    unsigned char CLK1_U0C0      : 1;  
    unsigned char CRS_U0C0       : 1;  
    unsigned char TXEPT_U0C0     : 1;  
    unsigned char CRD_U0C0       : 1;  
    unsigned char NCH_U0C0       : 1;  
    unsigned char CKPOL_U0C0     : 1;  
    unsigned char UFORM_U0C0     : 1;  
  } U0C0_bit;
} @ 0x3A4;
  
 
/* UART 0 transmit/receive control register 1 */ 
__no_init volatile union
{
  unsigned char U0C1;
  struct
  {
    unsigned char TE_U0C1        : 1;  
    unsigned char TI_U0C1        : 1;  
    unsigned char RE_U0C1        : 1;  
    unsigned char RI_U0C1        : 1;  
    unsigned char                : 1;  
    unsigned char                : 1;  
    unsigned char U0LCH          : 1;  
    unsigned char U0ERE          : 1;  
  } U0C1_bit;
} @ 0x3A5;
  
 __no_init volatile unsigned short U0RB @ 0x3A6;   /* UART 0 receive buffer */ 
  
 __no_init volatile unsigned char U0RBL @ 0x3A6;   /* UART 0 receive buffer (low byte) */ 
  
 __no_init volatile unsigned char U0RBH @ 0x3A7;   /* UART 0 receive buffer (high byte) */ 
  
 
/* UART 1 transmit/receive mode register */ 
__no_init volatile union
{
  unsigned char U1MR;
  struct
  {
    unsigned char SMD0_U1MR      : 1;  
    unsigned char SMD1_U1MR      : 1;  
    unsigned char SMD2_U1MR      : 1;  
    unsigned char CKDIR_U1MR     : 1;  
    unsigned char STPS_U1MR      : 1;  
    unsigned char PRY_U1MR       : 1;  
    unsigned char PRYE_U1MR      : 1;  
    unsigned char IOPOL_U1MR     : 1;  
  } U1MR_bit;
} @ 0x3A8;
  
 __no_init volatile unsigned char U1BRG @ 0x3A9;   /* UART 1 baud rate generator */ 
  
 __no_init volatile unsigned short U1TB @ 0x3AA;   /* UART 1 transmit buffer */ 
  
 __no_init volatile unsigned char U1TBL @ 0x3AA;   /* UART 1 transmit buffer (low byte) */ 
  
 __no_init volatile unsigned char U1TBH @ 0x3AB;   /* UART 1 tfransmit buffer (high byte) */ 
  
 __no_init volatile unsigned short U1C @ 0x3AC;   /* UART 1 transmit/receive control register */ 
  
 
/* UART 1 transmit/receive control register 0 */ 
__no_init volatile union
{
  unsigned char U1C0;
  struct
  {
    unsigned char CLK0_U1C0      : 1;  
    unsigned char CLK1_U1C0      : 1;  
    unsigned char CRS_U1C0       : 1;  
    unsigned char TXEPT_U1C0     : 1;  
    unsigned char CRD_U1C0       : 1;  
    unsigned char NCH_U1C0       : 1;  
    unsigned char CKPOL_U1C0     : 1;  
    unsigned char UFORM_U1C0     : 1;  
  } U1C0_bit;
} @ 0x3AC;
  
 
/* UART 1 transmit/receive control register 1 */ 
__no_init volatile union
{
  unsigned char U1C1;
  struct
  {
    unsigned char TE_U1C1        : 1;  
    unsigned char TI_U1C1        : 1;  
    unsigned char RE_U1C1        : 1;  
    unsigned char RI_U1C1        : 1;  
    unsigned char                : 1;  
    unsigned char                : 1;  
    unsigned char U1LCH          : 1;  
    unsigned char U1ERE          : 1;  
  } U1C1_bit;
} @ 0x3AD;
  
 __no_init volatile unsigned short U1RB @ 0x3AE;   /* UART 1 receive buffer */ 
  
 __no_init volatile unsigned char U1RBL @ 0x3AE;   /* UART 1 receive buffer (low byte) */ 
  
 __no_init volatile unsigned char U1RBH @ 0x3AF;   /* UART 1 receive buffer (high byte) */ 
  
 
/* UART transmit/receive control register 2 */ 
__no_init volatile union
{
  unsigned char UCON;
  struct
  {
    unsigned char U0IRS          : 1;  
    unsigned char U1IRS          : 1;  
    unsigned char U0RRM          : 1;  
    unsigned char U1RRM          : 1;  
    unsigned char CLKMD0         : 1;  
    unsigned char CLKMD1         : 1;  
    unsigned char RCSP           : 1;  
  } UCON_bit;
} @ 0x3B0;
  
 __no_init volatile unsigned char S3TRR @ 0x360;   /* SI/O3 transmit/receive register */ 
  
 
/* SI/O3 control register */ 
__no_init volatile union
{
  unsigned char S3C;
  struct
  {
    unsigned char SM30           : 1;  
    unsigned char SM31           : 1;  
    unsigned char SM32           : 1;  
    unsigned char SM33           : 1;  
    unsigned char SM34           : 1;  
    unsigned char SM35           : 1;  
    unsigned char SM36           : 1;  
    unsigned char SM37           : 1;  
  } S3C_bit;
} @ 0x362;
  
 __no_init volatile unsigned char S3BRG @ 0x363;   /* SI/O3 bit rate generator */ 
  
 __no_init volatile unsigned char S4TRR @ 0x364;   /* SI/O4 transmit/reveive register */ 
  
 
/* SI/O4 control register */ 
__no_init volatile union
{
  unsigned char S4C;
  struct
  {
    unsigned char SM40           : 1;  
    unsigned char SM41           : 1;  
    unsigned char SM42           : 1;  
    unsigned char SM43           : 1;  
    unsigned char SM44           : 1;  
    unsigned char SM45           : 1;  
    unsigned char SM46           : 1;  
    unsigned char SM47           : 1;  
  } S4C_bit;
} @ 0x366;
  
 __no_init volatile unsigned char S4BRG @ 0x367;   /* SI/O4 bit rate generator */ 
  
 
/* UART 0 special mode register 4 */ 
__no_init volatile union
{
  unsigned char U0SMR4;
  struct
  {
    unsigned char STAREQ_U0SMR4  : 1;  
    unsigned char RSTAREQ_U0SMR4 : 1;  
    unsigned char STPREQ_U0SMR4  : 1;  
    unsigned char STSPSEL_U0SMR4 : 1;  
    unsigned char ACKD_U0SMR4    : 1;  
    unsigned char ACKC_U0SMR4    : 1;  
    unsigned char SCLHI_U0SMR4   : 1;  
    unsigned char SWC9_U0SMR4    : 1;  
  } U0SMR4_bit;
} @ 0x36C;
  
 
/* UART 0 special mode register 3 */ 
__no_init volatile union
{
  unsigned char U0SMR3;
  struct
  {
    unsigned char                : 1;  
    unsigned char CKPH_U0SMR3    : 1;  
    unsigned char                : 1;  
    unsigned char NODC_U0SMR3    : 1;  
    unsigned char                : 1;  
    unsigned char DL0_U0SMR3     : 1;  
    unsigned char DL1_U0SMR3     : 1;  
    unsigned char DL2_U0SMR3     : 1;  
  } U0SMR3_bit;
} @ 0x36D;
  
 
/* UART 0 special mode register 2 */ 
__no_init volatile union
{
  unsigned char U0SMR2;
  struct
  {
    unsigned char IICM2_U0SMR2   : 1;  
    unsigned char CSC_U0SMR2     : 1;  
    unsigned char SWC_U0SMR2     : 1;  
    unsigned char ALS_U0SMR2     : 1;  
    unsigned char STAC_U0SMR2    : 1;  
    unsigned char SWC2_U0SMR2    : 1;  
    unsigned char SDHI_U0SMR2    : 1;  
  } U0SMR2_bit;
} @ 0x36E;
  
 
/* UART 0 special mode register */ 
__no_init volatile union
{
  unsigned char U0SMR;
  struct
  {
    unsigned char IICM_U0SMR     : 1;  
    unsigned char ABC_U0SMR      : 1;  
    unsigned char BBS_U0SMR      : 1;  
    unsigned char LSYN_U0SMR     : 1;  
    unsigned char ABSCS_U0SMR    : 1;  
    unsigned char ACSE_U0SMR     : 1;  
    unsigned char SSS_U0SMR      : 1;  
  } U0SMR_bit;
} @ 0x36F;
  
 
/* UART 1 special mode register 4 */ 
__no_init volatile union
{
  unsigned char U1SMR4;
  struct
  {
    unsigned char STAREQ_U1SMR4  : 1;  
    unsigned char RSTAREQ_U1SMR4 : 1;  
    unsigned char STPREQ_U1SMR4  : 1;  
    unsigned char STSPSEL_U1SMR4 : 1;  
    unsigned char ACKD_U1SMR4    : 1;  
    unsigned char ACKC_U1SMR4    : 1;  
    unsigned char SCLHI_U1SMR4   : 1;  
    unsigned char SWC9_U1SMR4    : 1;  
  } U1SMR4_bit;
} @ 0x370;
  
 
/* UART 1 special mode register 3 */ 
__no_init volatile union
{
  unsigned char U1SMR3;
  struct
  {
    unsigned char                : 1;  
    unsigned char CKPH_U1SMR3    : 1;  
    unsigned char                : 1;  
    unsigned char NODC_U1SMR3    : 1;  
    unsigned char                : 1;  
    unsigned char DL0_U1SMR3     : 1;  
    unsigned char DL1_U1SMR3     : 1;  
    unsigned char DL2_U1SMR3     : 1;  
  } U1SMR3_bit;
} @ 0x371;
  
 
/* UART 1 special mode register 2 */ 
__no_init volatile union
{
  unsigned char U1SMR2;
  struct
  {
    unsigned char IICM2_U1SMR2   : 1;  
    unsigned char CSC_U1SMR2     : 1;  
    unsigned char SWC_U1SMR2     : 1;  
    unsigned char ALS_U1SMR2     : 1;  
    unsigned char STAC_U1SMR2    : 1;  
    unsigned char SWC2_U1SMR2    : 1;  
    unsigned char SDHI_U1SMR2    : 1;  
  } U1SMR2_bit;
} @ 0x372;
  
 
/* UART 1 special mode register */ 
__no_init volatile union
{
  unsigned char U1SMR;
  struct
  {
    unsigned char IICM_U1SMR     : 1;  
    unsigned char ABC_U1SMR      : 1;  
    unsigned char BBS_U1SMR      : 1;  
    unsigned char LSYN_U1SMR     : 1;  
    unsigned char ABSCS_U1SMR    : 1;  
    unsigned char ACSE_U1SMR     : 1;  
    unsigned char SSS_U1SMR      : 1;  
  } U1SMR_bit;
} @ 0x373;
  
 
/* UART 2 special mode register 4 */ 
__no_init volatile union
{
  unsigned char U2SMR4;
  struct
  {
    unsigned char STAREQ_U2SMR4  : 1;  
    unsigned char RSTAREQ_U2SMR4 : 1;  
    unsigned char STPREQ_U2SMR4  : 1;  
    unsigned char STSPSEL_U2SMR4 : 1;  
    unsigned char ACKD_U2SMR4    : 1;  
    unsigned char ACKC_U2SMR4    : 1;  
    unsigned char SCLHI_U2SMR4   : 1;  
    unsigned char SWC9_U2SMR4    : 1;  
  } U2SMR4_bit;
} @ 0x374;
  
 
/* UART 2 special mode register 3 */ 
__no_init volatile union
{
  unsigned char U2SMR3;
  struct
  {
    unsigned char                : 1;  
    unsigned char CKPH_U2SMR3    : 1;  
    unsigned char                : 1;  
    unsigned char NODC_U2SMR3    : 1;  
    unsigned char                : 1;  
    unsigned char DL0_U2SMR3     : 1;  
    unsigned char DL1_U2SMR3     : 1;  
    unsigned char DL2_U2SMR3     : 1;  
  } U2SMR3_bit;
} @ 0x375;
  
 
/* UART 2 special mode register 2 */ 
__no_init volatile union
{
  unsigned char U2SMR2;
  struct
  {
    unsigned char IICM2_U2SMR2   : 1;  
    unsigned char CSC_U2SMR2     : 1;  
    unsigned char SWC_U2SMR2     : 1;  
    unsigned char ALS_U2SMR2     : 1;  
    unsigned char STAC_U2SMR2    : 1;  
    unsigned char SWC2_U2SMR2    : 1;  
    unsigned char SDHI_U2SMR2    : 1;  
  } U2SMR2_bit;
} @ 0x376;
  
 
/* UART 2 special mode register */ 
__no_init volatile union
{
  unsigned char U2SMR;
  struct
  {
    unsigned char IICM_U2SMR     : 1;  
    unsigned char ABC_U2SMR      : 1;  
    unsigned char BBS_U2SMR      : 1;  
    unsigned char LSYN_U2SMR     : 1;  
    unsigned char ABSCS_U2SMR    : 1;  
    unsigned char ACSE_U2SMR     : 1;  
    unsigned char SSS_U2SMR      : 1;  
  } U2SMR_bit;
} @ 0x377;
  
 
/* UART 2 transmit/receive mode register */ 
__no_init volatile union
{
  unsigned char U2MR;
  struct
  {
    unsigned char SMD0_U2MR      : 1;  
    unsigned char SMD1_U2MR      : 1;  
    unsigned char SMD2_U2MR      : 1;  
    unsigned char CKDIR_U2MR     : 1;  
    unsigned char STPS_U2MR      : 1;  
    unsigned char PRY_U2MR       : 1;  
    unsigned char PRYE_U2MR      : 1;  
    unsigned char IOPOL_U2MR     : 1;  
  } U2MR_bit;
} @ 0x378;
  
 __no_init volatile unsigned char U2BRG @ 0x379;   /* UART 2 bit rate generator */ 
  
 __no_init volatile unsigned short U2TB @ 0x37A;   /* UART 2 transmit buffer register */ 
  
 __no_init volatile unsigned char U2TBL @ 0x37A;   /* UART 2 transmit buffer register (low byte) */ 
  
 __no_init volatile unsigned char U2TBH @ 0x37B;   /* UART 2 transmit buffer register (high byte) */ 
  
 
/* UART 2 transmit/receive control register 0 */ 
__no_init volatile union
{
  unsigned char U2C0;
  struct
  {
    unsigned char CLK0_U2C0      : 1;  
    unsigned char CLK1_U2C0      : 1;  
    unsigned char CRS_U2C0       : 1;  
    unsigned char TXEPT_U2C0     : 1;  
    unsigned char CRD_U2C0       : 1;  
    unsigned char NCH_U2C0       : 1;  
    unsigned char CKPOL_U2C0     : 1;  
    unsigned char UFORM_U2C0     : 1;  
  } U2C0_bit;
} @ 0x37C;
  
 
/* UART 2 transmit/receive control register 1 */ 
__no_init volatile union
{
  unsigned char U2C1;
  struct
  {
    unsigned char TE_U2C1        : 1;  
    unsigned char TI_U2C1        : 1;  
    unsigned char RE_U2C1        : 1;  
    unsigned char RI_U2C1        : 1;  
    unsigned char U2IRS          : 1;  
    unsigned char U2RRM          : 1;  
    unsigned char U2LCH          : 1;  
    unsigned char U2ERE          : 1;  
  } U2C1_bit;
} @ 0x37D;
  
 __no_init volatile unsigned short U2RB @ 0x37E;   /* UART 2 receive buffer register */ 
  
 __no_init volatile unsigned char U2RBL @ 0x37E;   /* UART 2 receive buffer register (low byte) */ 
  
 __no_init volatile unsigned char U2RBH @ 0x37F;   /* UART 2 receive buffer register (high byte) */ 
  
 

/*-------------------------------------------------------------------------
 *   Flash control register
 *-------------------------------------------------------------------------*/

 __no_init volatile unsigned char FIDR @ 0x1B4;   /* Flash identification register */ 
  
 
/* Flash memory control register 1 */ 
__no_init volatile union
{
  unsigned char FMR1;
  struct
  {
    unsigned char                : 1;  
    unsigned char FMR11          : 1;  
    unsigned char                : 4;  
    unsigned char FMR06          : 1;  
  } FMR1_bit;
} @ 0x1B5;
  
 
/* Flash memory control register 0 */ 
__no_init volatile union
{
  unsigned char FMR0;
  struct
  {
    unsigned char FMR00          : 1;  
    unsigned char FMR01          : 1;  
    unsigned char FMR02          : 1;  
    unsigned char FMSTP          : 1;  
    unsigned char                : 1;  
    unsigned char FMR05          : 1;  
    unsigned char FMR06          : 1;  
    unsigned char FMR07          : 1;  
  } FMR0_bit;
} @ 0x1B7;
  
 

/*-------------------------------------------------------------------------
 *   CRC register
 *-------------------------------------------------------------------------*/

 __no_init volatile unsigned short CRCD @ 0x3BC;   /* CRC data register */ 
  
 __no_init volatile unsigned char CRCDL @ 0x3BC;   /* CRC data register (low byte) */ 
  
 __no_init volatile unsigned char CRCDH @ 0x3BD;   /* CRC data register (high byte) */ 
  
 __no_init volatile unsigned char CRCIN @ 0x3BE;   /* CRC input register */ 
  
 

/*-------------------------------------------------------------------------
 *   A/D Converter
 *-------------------------------------------------------------------------*/

 __no_init volatile unsigned short AD0 @ 0x3C0;   /* A/D register 0 */ 
  
 __no_init volatile unsigned char AD0L @ 0x3C0;   /* A/D register 0 (low byte) */ 
  
 __no_init volatile unsigned char AD0H @ 0x3C1;   /* A/D register 0 (high byte) */ 
  
 __no_init volatile unsigned short AD1 @ 0x3C2;   /* A/D register 1 */ 
  
 __no_init volatile unsigned char AD1L @ 0x3C2;   /* A/D register 1 (low byte) */ 
  
 __no_init volatile unsigned char AD1H @ 0x3C3;   /* A/D register 1 (high byte) */ 
  
 __no_init volatile unsigned short AD2 @ 0x3C4;   /* A/D register 2 */ 
  
 __no_init volatile unsigned char AD2L @ 0x3C4;   /* A/D register 2 (low byte) */ 
  
 __no_init volatile unsigned char AD2H @ 0x3C5;   /* A/D register 2 (high byte) */ 
  
 __no_init volatile unsigned short AD3 @ 0x3C6;   /* A/D register 3 */ 
  
 __no_init volatile unsigned char AD3L @ 0x3C6;   /* A/D register 3 (low byte) */ 
  
 __no_init volatile unsigned char AD3H @ 0x3C7;   /* A/D register 3 (high byte) */ 
  
 __no_init volatile unsigned short AD4 @ 0x3C8;   /* A/D register 4 */ 
  
 __no_init volatile unsigned char AD4L @ 0x3C8;   /* A/D register 4 (low byte) */ 
  
 __no_init volatile unsigned char AD4H @ 0x3C9;   /* A/D register 4 (high byte) */ 
  
 __no_init volatile unsigned short AD5 @ 0x3CA;   /* A/D register 5 */ 
  
 __no_init volatile unsigned char AD5L @ 0x3CA;   /* A/D register 5 (low byte) */ 
  
 __no_init volatile unsigned char AD5H @ 0x3CB;   /* A/D register 5 (high byte) */ 
  
 __no_init volatile unsigned short AD6 @ 0x3CC;   /* A/D register 6 */ 
  
 __no_init volatile unsigned char AD6L @ 0x3CC;   /* A/D register 6 (low byte) */ 
  
 __no_init volatile unsigned char AD6H @ 0x3CD;   /* A/D register 6 (high byte) */ 
  
 __no_init volatile unsigned short AD7 @ 0x3CE;   /* A/D register 7 */ 
  
 __no_init volatile unsigned char AD7L @ 0x3CE;   /* A/D register 7 (low byte) */ 
  
 __no_init volatile unsigned char AD7H @ 0x3CF;   /* A/D register 7 (high byte) */ 
  
 
/* A/D control register 2 */ 
__no_init volatile union
{
  unsigned char ADCON2;
  struct
  {
    unsigned char SMP            : 1;  
    unsigned char ADGSEL0        : 1;  
    unsigned char ADGSEL1        : 1;  
    unsigned char                : 1;  
    unsigned char CKS2           : 1;  
  } ADCON2_bit;
} @ 0x3D4;
  
 
/* A/D control register 0 */ 
__no_init volatile union
{
  unsigned char ADCON0;
  struct
  {
    unsigned char CH0            : 1;  
    unsigned char CH1            : 1;  
    unsigned char CH2            : 1;  
    unsigned char MD0            : 1;  
    unsigned char MD1            : 1;  
    unsigned char TRG            : 1;  
    unsigned char ADST           : 1;  
    unsigned char CKS0           : 1;  
  } ADCON0_bit;
} @ 0x3D6;
  
 
/* A/D control register 1 */ 
__no_init volatile union
{
  unsigned char ADCON1;
  struct
  {
    unsigned char SCAN0          : 1;  
    unsigned char SCAN1          : 1;  
    unsigned char MD2            : 1;  
    unsigned char BITS           : 1;  
    unsigned char CKS1           : 1;  
    unsigned char VCUT           : 1;  
    unsigned char OPA0           : 1;  
    unsigned char OPA1           : 1;  
  } ADCON1_bit;
} @ 0x3D7;
  
 

/*-------------------------------------------------------------------------
 *   D-A Converter
 *-------------------------------------------------------------------------*/

 __no_init volatile unsigned char DA0 @ 0x3D8;   /* D-A register 0 */ 
  
 __no_init volatile unsigned char DA1 @ 0x3DA;   /* D-A register 1 */ 
  
 
/* D-A control register */ 
__no_init volatile union
{
  unsigned char DACON;
  struct
  {
    unsigned char DA0E           : 1;  
    unsigned char DA1E           : 1;  
  } DACON_bit;
} @ 0x3DC;
  
 

/*-------------------------------------------------------------------------
 *   Power supply
 *-------------------------------------------------------------------------*/

 
/* Power supply detection register 1 */ 
__no_init volatile union
{
  unsigned char VCR1;
  struct
  {
    unsigned char                : 1;  
    unsigned char                : 1;  
    unsigned char                : 1;  
    unsigned char VC13           : 1;  
  } VCR1_bit;
} @ 0x019;
  
 
/* Power supply detection register 2 */ 
__no_init volatile union
{
  unsigned char VCR2;
  struct
  {
    unsigned char                : 1;  
    unsigned char                : 1;  
    unsigned char                : 1;  
    unsigned char                : 1;  
    unsigned char                : 1;  
    unsigned char VC25           : 1;  
    unsigned char VC26           : 1;  
    unsigned char VC27           : 1;  
  } VCR2_bit;
} @ 0x01A;
  
 
/* Power supply down detection register */ 
__no_init volatile union
{
  unsigned char D4INT;
  struct
  {
    unsigned char D40            : 1;  
    unsigned char D41            : 1;  
    unsigned char D42            : 1;  
    unsigned char D43            : 1;  
    unsigned char DF0            : 1;  
    unsigned char DF1            : 1;  
  } D4INT_bit;
} @ 0x01F;
  
 

/*-------------------------------------------------------------------------
 *   Port Registers
 *-------------------------------------------------------------------------*/

 
/* Port P14 register */ 
__no_init volatile union
{
  unsigned char PC14;
  struct
  {
    unsigned char P140           : 1;  
    unsigned char P141           : 1;  
    unsigned char                : 1;  
    unsigned char                : 1;  
    unsigned char PD140          : 1;  
    unsigned char PD141          : 1;  
  } PC14_bit;
} @ 0x3DE;
  
 
/* Pull-up register 3 */ 
__no_init volatile union
{
  unsigned char PUR3;
  struct
  {
    unsigned char PU30           : 1;  
    unsigned char PU31           : 1;  
    unsigned char PU32           : 1;  
    unsigned char PU33           : 1;  
    unsigned char PU34           : 1;  
    unsigned char PU35           : 1;  
    unsigned char PU36           : 1;  
    unsigned char PU37           : 1;  
  } PUR3_bit;
} @ 0x3DF;
  
 
/* Port P0 register */ 
__no_init volatile union
{
  unsigned char P0;
  struct
  {
    unsigned char P0_0           : 1;  
    unsigned char P0_1           : 1;  
    unsigned char P0_2           : 1;  
    unsigned char P0_3           : 1;  
    unsigned char P0_4           : 1;  
    unsigned char P0_5           : 1;  
    unsigned char P0_6           : 1;  
    unsigned char P0_7           : 1;  
  } P0_bit;
} @ 0x3E0;
  
 
/* Port P1 register */ 
__no_init volatile union
{
  unsigned char P1;
  struct
  {
    unsigned char P1_0           : 1;  
    unsigned char P1_1           : 1;  
    unsigned char P1_2           : 1;  
    unsigned char P1_3           : 1;  
    unsigned char P1_4           : 1;  
    unsigned char P1_5           : 1;  
    unsigned char P1_6           : 1;  
    unsigned char P1_7           : 1;  
  } P1_bit;
} @ 0x3E1;
  
 __no_init volatile unsigned short P01 @ 0x3E0;   /* Port P0 and P1 register */ 
  
 
/* Port P0 direction register */ 
__no_init volatile union
{
  unsigned char PD0;
  struct
  {
    unsigned char PD0_0          : 1;  
    unsigned char PD0_1          : 1;  
    unsigned char PD0_2          : 1;  
    unsigned char PD0_3          : 1;  
    unsigned char PD0_4          : 1;  
    unsigned char PD0_5          : 1;  
    unsigned char PD0_6          : 1;  
    unsigned char PD0_7          : 1;  
  } PD0_bit;
} @ 0x3E2;
  
 
/* Port P1 direction register */ 
__no_init volatile union
{
  unsigned char PD1;
  struct
  {
    unsigned char PD1_0          : 1;  
    unsigned char PD1_1          : 1;  
    unsigned char PD1_2          : 1;  
    unsigned char PD1_3          : 1;  
    unsigned char PD1_4          : 1;  
    unsigned char PD1_5          : 1;  
    unsigned char PD1_6          : 1;  
    unsigned char PD1_7          : 1;  
  } PD1_bit;
} @ 0x3E3;
  
 __no_init volatile unsigned short PD01 @ 0x3E2;   /* Port P0 and P1 direction register */ 
  
 
/* Port P2 register */ 
__no_init volatile union
{
  unsigned char P2;
  struct
  {
    unsigned char P2_0           : 1;  
    unsigned char P2_1           : 1;  
    unsigned char P2_2           : 1;  
    unsigned char P2_3           : 1;  
    unsigned char P2_4           : 1;  
    unsigned char P2_5           : 1;  
    unsigned char P2_6           : 1;  
    unsigned char P2_7           : 1;  
  } P2_bit;
} @ 0x3E4;
  
 
/* Port P3 register */ 
__no_init volatile union
{
  unsigned char P3;
  struct
  {
    unsigned char P3_0           : 1;  
    unsigned char P3_1           : 1;  
    unsigned char P3_2           : 1;  
    unsigned char P3_3           : 1;  
    unsigned char P3_4           : 1;  
    unsigned char P3_5           : 1;  
    unsigned char P3_6           : 1;  
    unsigned char P3_7           : 1;  
  } P3_bit;
} @ 0x3E5;
  
 __no_init volatile unsigned short P23 @ 0x3E4;   /* Port P2 and P3 register */ 
  
 
/* Port P2 direction register */ 
__no_init volatile union
{
  unsigned char PD2;
  struct
  {
    unsigned char PD2_0          : 1;  
    unsigned char PD2_1          : 1;  
    unsigned char PD2_2          : 1;  
    unsigned char PD2_3          : 1;  
    unsigned char PD2_4          : 1;  
    unsigned char PD2_5          : 1;  
    unsigned char PD2_6          : 1;  
    unsigned char PD2_7          : 1;  
  } PD2_bit;
} @ 0x3E6;
  
 
/* Port P3 direction register */ 
__no_init volatile union
{
  unsigned char PD3;
  struct
  {
    unsigned char PD3_0          : 1;  
    unsigned char PD3_1          : 1;  
    unsigned char PD3_2          : 1;  
    unsigned char PD3_3          : 1;  
    unsigned char PD3_4          : 1;  
    unsigned char PD3_5          : 1;  
    unsigned char PD3_6          : 1;  
    unsigned char PD3_7          : 1;  
  } PD3_bit;
} @ 0x3E7;
  
 __no_init volatile unsigned short PD23 @ 0x3E6;   /* Port P2 and P3 direction register */ 
  
 
/* Port P4 register */ 
__no_init volatile union
{
  unsigned char P4;
  struct
  {
    unsigned char P4_0           : 1;  
    unsigned char P4_1           : 1;  
    unsigned char P4_2           : 1;  
    unsigned char P4_3           : 1;  
    unsigned char P4_4           : 1;  
    unsigned char P4_5           : 1;  
    unsigned char P4_6           : 1;  
    unsigned char P4_7           : 1;  
  } P4_bit;
} @ 0x3E8;
  
 
/* Port P5 register */ 
__no_init volatile union
{
  unsigned char P5;
  struct
  {
    unsigned char P5_0           : 1;  
    unsigned char P5_1           : 1;  
    unsigned char P5_2           : 1;  
    unsigned char P5_3           : 1;  
    unsigned char P5_4           : 1;  
    unsigned char P5_5           : 1;  
    unsigned char P5_6           : 1;  
    unsigned char P5_7           : 1;  
  } P5_bit;
} @ 0x3E9;
  
 __no_init volatile unsigned short P45 @ 0x3E8;   /* Port P4 and P5 register */ 
  
 
/* Port P4 direction register */ 
__no_init volatile union
{
  unsigned char PD4;
  struct
  {
    unsigned char PD4_0          : 1;  
    unsigned char PD4_1          : 1;  
    unsigned char PD4_2          : 1;  
    unsigned char PD4_3          : 1;  
    unsigned char PD4_4          : 1;  
    unsigned char PD4_5          : 1;  
    unsigned char PD4_6          : 1;  
    unsigned char PD4_7          : 1;  
  } PD4_bit;
} @ 0x3EA;
  
 
/* Port P5 direction register */ 
__no_init volatile union
{
  unsigned char PD5;
  struct
  {
    unsigned char PD5_0          : 1;  
    unsigned char PD5_1          : 1;  
    unsigned char PD5_2          : 1;  
    unsigned char PD5_3          : 1;  
    unsigned char PD5_4          : 1;  
    unsigned char PD5_5          : 1;  
    unsigned char PD5_6          : 1;  
    unsigned char PD5_7          : 1;  
  } PD5_bit;
} @ 0x3EB;
  
 __no_init volatile unsigned short PD45 @ 0x3EA;   /* Port P4 and P5 direction register */ 
  
 
/* Port P6 register */ 
__no_init volatile union
{
  unsigned char P6;
  struct
  {
    unsigned char P6_0           : 1;  
    unsigned char P6_1           : 1;  
    unsigned char P6_2           : 1;  
    unsigned char P6_3           : 1;  
    unsigned char P6_4           : 1;  
    unsigned char P6_5           : 1;  
    unsigned char P6_6           : 1;  
    unsigned char P6_7           : 1;  
  } P6_bit;
} @ 0x3EC;
  
 
/* Port P7 register */ 
__no_init volatile union
{
  unsigned char P7;
  struct
  {
    unsigned char P7_0           : 1;  
    unsigned char P7_1           : 1;  
    unsigned char P7_2           : 1;  
    unsigned char P7_3           : 1;  
    unsigned char P7_4           : 1;  
    unsigned char P7_5           : 1;  
    unsigned char P7_6           : 1;  
    unsigned char P7_7           : 1;  
  } P7_bit;
} @ 0x3ED;
  
 __no_init volatile unsigned short P67 @ 0x3EC;   /* Port P6 and P7 register */ 
  
 
/* Port P6 direction register */ 
__no_init volatile union
{
  unsigned char PD6;
  struct
  {
    unsigned char PD6_0          : 1;  
    unsigned char PD6_1          : 1;  
    unsigned char PD6_2          : 1;  
    unsigned char PD6_3          : 1;  
    unsigned char PD6_4          : 1;  
    unsigned char PD6_5          : 1;  
    unsigned char PD6_6          : 1;  
    unsigned char PD6_7          : 1;  
  } PD6_bit;
} @ 0x3EE;
  
 
/* Port P7 direction register */ 
__no_init volatile union
{
  unsigned char PD7;
  struct
  {
    unsigned char PD7_0          : 1;  
    unsigned char PD7_1          : 1;  
    unsigned char PD7_2          : 1;  
    unsigned char PD7_3          : 1;  
    unsigned char PD7_4          : 1;  
    unsigned char PD7_5          : 1;  
    unsigned char PD7_6          : 1;  
    unsigned char PD7_7          : 1;  
  } PD7_bit;
} @ 0x3EF;
  
 __no_init volatile unsigned short PD67 @ 0x3EE;   /* Port P6 and P7 direction register */ 
  
 
/* Port P8 register */ 
__no_init volatile union
{
  unsigned char P8;
  struct
  {
    unsigned char P8_0           : 1;  
    unsigned char P8_1           : 1;  
    unsigned char P8_2           : 1;  
    unsigned char P8_3           : 1;  
    unsigned char P8_4           : 1;  
    unsigned char P8_5           : 1;  
    unsigned char P8_6           : 1;  
    unsigned char P8_7           : 1;  
  } P8_bit;
} @ 0x3F0;
  
 
/* Port P9 register */ 
__no_init volatile union
{
  unsigned char P9;
  struct
  {
    unsigned char P9_0           : 1;  
    unsigned char P9_1           : 1;  
    unsigned char P9_2           : 1;  
    unsigned char P9_3           : 1;  
    unsigned char P9_4           : 1;  
    unsigned char P9_5           : 1;  
    unsigned char P9_6           : 1;  
    unsigned char P9_7           : 1;  
  } P9_bit;
} @ 0x3F1;
  
 __no_init volatile unsigned short P89 @ 0x3F0;   /* Port P8 and P9 register */ 
  
 
/* Port P8 direction register */ 
__no_init volatile union
{
  unsigned char PD8;
  struct
  {
    unsigned char PD8_0          : 1;  
    unsigned char PD8_1          : 1;  
    unsigned char PD8_2          : 1;  
    unsigned char PD8_3          : 1;  
    unsigned char PD8_4          : 1;  
    unsigned char                : 1;  
    unsigned char PD8_6          : 1;  
    unsigned char PD8_7          : 1;  
  } PD8_bit;
} @ 0x3F2;
  
 
/* Port P9 direction register */ 
__no_init volatile union
{
  unsigned char PD9;
  struct
  {
    unsigned char PD9_0          : 1;  
    unsigned char PD9_1          : 1;  
    unsigned char PD9_2          : 1;  
    unsigned char PD9_3          : 1;  
    unsigned char PD9_4          : 1;  
    unsigned char PD9_5          : 1;  
    unsigned char PD9_6          : 1;  
    unsigned char PD9_7          : 1;  
  } PD9_bit;
} @ 0x3F3;
  
 __no_init volatile unsigned short PD89 @ 0x3F2;   /* Port P8 and P9 direction register */ 
  
 
/* Port P10 register */ 
__no_init volatile union
{
  unsigned char P10;
  struct
  {
    unsigned char P10_0          : 1;  
    unsigned char P10_1          : 1;  
    unsigned char P10_2          : 1;  
    unsigned char P10_3          : 1;  
    unsigned char P10_4          : 1;  
    unsigned char P10_5          : 1;  
    unsigned char P10_6          : 1;  
    unsigned char P10_7          : 1;  
  } P10_bit;
} @ 0x3F4;
  
 
/* Port P11 register */ 
__no_init volatile union
{
  unsigned char P11;
  struct
  {
    unsigned char P11_0          : 1;  
    unsigned char P11_1          : 1;  
    unsigned char P11_2          : 1;  
    unsigned char P11_3          : 1;  
    unsigned char P11_4          : 1;  
    unsigned char P11_5          : 1;  
    unsigned char P11_6          : 1;  
    unsigned char P11_7          : 1;  
  } P11_bit;
} @ 0x3F5;
  
 
/* Port P10 direction register */ 
__no_init volatile union
{
  unsigned char PD10;
  struct
  {
    unsigned char PD10_0         : 1;  
    unsigned char PD10_1         : 1;  
    unsigned char PD10_2         : 1;  
    unsigned char PD10_3         : 1;  
    unsigned char PD10_4         : 1;  
    unsigned char PD10_5         : 1;  
    unsigned char PD10_6         : 1;  
    unsigned char PD10_7         : 1;  
  } PD10_bit;
} @ 0x3F6;
  
 
/* Port P11 direction register */ 
__no_init volatile union
{
  unsigned char PD11;
  struct
  {
    unsigned char PD11_0         : 1;  
    unsigned char PD11_1         : 1;  
    unsigned char PD11_2         : 1;  
    unsigned char PD11_3         : 1;  
    unsigned char PD11_4         : 1;  
    unsigned char PD11_5         : 1;  
    unsigned char PD11_6         : 1;  
    unsigned char PD11_7         : 1;  
  } PD11_bit;
} @ 0x3F7;
  
 
/* Port P12 register */ 
__no_init volatile union
{
  unsigned char P12;
  struct
  {
    unsigned char P12_0          : 1;  
    unsigned char P12_1          : 1;  
    unsigned char P12_2          : 1;  
    unsigned char P12_3          : 1;  
    unsigned char P12_4          : 1;  
    unsigned char P12_5          : 1;  
    unsigned char P12_6          : 1;  
    unsigned char P12_7          : 1;  
  } P12_bit;
} @ 0x3F8;
  
 
/* Port P13 register */ 
__no_init volatile union
{
  unsigned char P13;
  struct
  {
    unsigned char P13_0          : 1;  
    unsigned char P13_1          : 1;  
    unsigned char P13_2          : 1;  
    unsigned char P13_3          : 1;  
    unsigned char P13_4          : 1;  
    unsigned char P13_5          : 1;  
    unsigned char P13_6          : 1;  
    unsigned char P13_7          : 1;  
  } P13_bit;
} @ 0x3F9;
  
 
/* Port P12 direction register */ 
__no_init volatile union
{
  unsigned char PD12;
  struct
  {
    unsigned char PD12_0         : 1;  
    unsigned char PD12_1         : 1;  
    unsigned char PD12_2         : 1;  
    unsigned char PD12_3         : 1;  
    unsigned char PD12_4         : 1;  
    unsigned char PD12_5         : 1;  
    unsigned char PD12_6         : 1;  
    unsigned char PD12_7         : 1;  
  } PD12_bit;
} @ 0x3FA;
  
 
/* Port P13 direction register */ 
__no_init volatile union
{
  unsigned char PD13;
  struct
  {
    unsigned char PD13_0         : 1;  
    unsigned char PD13_1         : 1;  
    unsigned char PD13_2         : 1;  
    unsigned char PD13_3         : 1;  
    unsigned char PD13_4         : 1;  
    unsigned char PD13_5         : 1;  
    unsigned char PD13_6         : 1;  
    unsigned char PD13_7         : 1;  
  } PD13_bit;
} @ 0x3FB;
  
 __no_init volatile unsigned short PD1213 @ 0x3FA;   /* Port P12 and P13 direction register */ 
  
 
/* Pull-up register 0 */ 
__no_init volatile union
{
  unsigned char PUR0;
  struct
  {
    unsigned char PU00           : 1;  
  } PUR0_bit;
} @ 0x3FC;
  
 __no_init volatile unsigned char PUR1 @ 0x3FD;   /* Pull-up register 1 */ 
  
 __no_init volatile unsigned short PUR01 @ 0x3FC;   /* Pull-up register 0 and 1 */ 
  
 __no_init volatile unsigned char PUR2 @ 0x3FE;   /* Pull-up register 2 */ 
  
 __no_init volatile unsigned char PCR @ 0x3FF;   /* Port control register */ 
  
 


#pragma language=default
#endif  /* __IAR_SYSTEMS_ICC__  */
#ifdef __IAR_SYSTEMS_ASM__

/***************************************************************************
 *   Assembler definitions
 ***************************************************************************/


/*-------------------------------------------------------------------------
 *   Processor Registers
 *-------------------------------------------------------------------------*/
 
/* Processor Mode Register */ 
PM                        DEFINE 0x004 
/* Processor Mode Register 0 */ 
PM0                       DEFINE 0x004
PM00                      DEFINE 0   
PM01                      DEFINE 1   
PM02                      DEFINE 2   
PM03                      DEFINE 3   
PM04                      DEFINE 4   
PM05                      DEFINE 5   
PM06                      DEFINE 6   
PM07                      DEFINE 7    
/* Processor Mode Register 1 */ 
PM1                       DEFINE 0x005
PM10                      DEFINE 0   
PM11                      DEFINE 1   
PM12                      DEFINE 2   
PM13                      DEFINE 3   
PM14                      DEFINE 4   
PM15                      DEFINE 5    
PM17                      DEFINE 7    
/* System clock control register 0 */ 
CM0                       DEFINE 0x006
CM00                      DEFINE 0   
CM01                      DEFINE 1   
CM02                      DEFINE 2   
CM03                      DEFINE 3   
CM04                      DEFINE 4   
CM05                      DEFINE 5   
CM06                      DEFINE 6   
CM07                      DEFINE 7    
/* System clock control register 1 */ 
CM1                       DEFINE 0x007
CM10                      DEFINE 0   
CM11                      DEFINE 1      
CM15                      DEFINE 5   
CM16                      DEFINE 6   
CM17                      DEFINE 7    
/* System clock control register */ 
CM                        DEFINE 0x006 
/* Chip select control register */ 
CSR                       DEFINE 0x008
CS0                       DEFINE 0   
CS1                       DEFINE 1   
CS2                       DEFINE 2   
CS3                       DEFINE 3   
CS0W                      DEFINE 4   
CS1W                      DEFINE 5   
CS2W                      DEFINE 6   
CS3W                      DEFINE 7    
/* Protect register */ 
PRCR                      DEFINE 0x00A
PRC0                      DEFINE 0   
PRC1                      DEFINE 1   
PRC2                      DEFINE 2    
/* Oscillation stop detection register */ 
CM2                       DEFINE 0x00C
CM20                      DEFINE 0   
CM21                      DEFINE 1   
CM22                      DEFINE 2   
CM23                      DEFINE 3      
CM27                      DEFINE 7    
/* Chip select expansion control register */ 
CSE                       DEFINE 0x01B 
/* PLC control register 0 */ 
PLC0                      DEFINE 0x01C
PLC00                     DEFINE 0   
PLC01                     DEFINE 1   
PLC02                     DEFINE 2    
PLC07                     DEFINE 7    
/* Processor Mode Register 2 */ 
PM2                       DEFINE 0x01E
PM20                      DEFINE 0   
PM21                      DEFINE 1   
PM22                      DEFINE 2    
/* Peripheral clock select register */ 
PCLKR                     DEFINE 0x25E 

/*-------------------------------------------------------------------------
 *   Watchdog Timer
 *-------------------------------------------------------------------------*/
 
/* Watchdog timer start register */ 
WDTS                      DEFINE 0x00E 
/* Watchdog timer control register */ 
WDC                       DEFINE 0x00F 

/*-------------------------------------------------------------------------
 *   Interrupt Control Register
 *-------------------------------------------------------------------------*/
 
/* Address match interrupt enable */ 
AIER                      DEFINE 0x009 
/* Address match interrupt register 0 (low) */ 
RMAD00                    DEFINE 0x010 
/* Address match interrupt register 0 (mid) */ 
RMAD01                    DEFINE 0x011 
/* Address match interrupt register 0 (high) */ 
RMAD02                    DEFINE 0x012 
/* Address match interrupt register 1 (low) */ 
RMAD10                    DEFINE 0x014 
/* Address match interrupt register 1 (mid) */ 
RMAD11                    DEFINE 0x015 
/* Address match interrupt register 1 (high) */ 
RMAD12                    DEFINE 0x016 
/* INT3 interrupt control register */ 
INT3IC                    DEFINE 0x044
ILVL                      DEFINE 0   
IR                        DEFINE 3   
POL                       DEFINE 4    
/* Timer B5 interrupt control register */ 
TB5IC                     DEFINE 0x045
ILVL                      DEFINE 0   
IR                        DEFINE 3    
/* UART0 BUS collision detection interrupt control register */ 
U0BCNIC                   DEFINE 0x046
ILVL                      DEFINE 0   
IR                        DEFINE 3    
/* Timer B4 interrupt control register */ 
TB4IC                     DEFINE 0x046
ILVL                      DEFINE 0   
IR                        DEFINE 3    
/* UART1 BUS collision detection interrupt control register */ 
U1BCNIC                   DEFINE 0x047
ILVL                      DEFINE 0   
IR                        DEFINE 3    
/* Timer B3 interrupt control register */ 
TB3IC                     DEFINE 0x047
ILVL                      DEFINE 0   
IR                        DEFINE 3    
/* SI/O4 interrupt control register */ 
S4IC                      DEFINE 0x048
ILVL                      DEFINE 0   
IR                        DEFINE 3    
/* INT5 interrupt control register */ 
INT5IC                    DEFINE 0x048
ILVL                      DEFINE 0   
IR                        DEFINE 3   
POL                       DEFINE 4    
/* SI/O3 interrupt control register */ 
S3IC                      DEFINE 0x049
ILVL                      DEFINE 0   
IR                        DEFINE 3    
/* INT4 interrupt control register */ 
INT4IC                    DEFINE 0x049
ILVL                      DEFINE 0   
IR                        DEFINE 3   
POL                       DEFINE 4    
/* UART2 Bus collision detection interrupt control register */ 
BCNIC                     DEFINE 0x04A
ILVL                      DEFINE 0   
IR                        DEFINE 3    
/* DMA0 interrupt control register */ 
DMA0IC                    DEFINE 0x04B
ILVL                      DEFINE 0   
IR                        DEFINE 3    
/* DMA1 interrupt control register */ 
DMA1IC                    DEFINE 0x04C
ILVL                      DEFINE 0   
IR                        DEFINE 3    
/* Key input interrupt control register */ 
KUPIC                     DEFINE 0x04D
ILVL                      DEFINE 0   
IR                        DEFINE 3    
/* AD conversion interrupt control register */ 
ADIC                      DEFINE 0x04E
ILVL                      DEFINE 0   
IR                        DEFINE 3    
/* UART2 transmit interrupt control register */ 
S2TIC                     DEFINE 0x04F
ILVL                      DEFINE 0   
IR                        DEFINE 3    
/* UART2 receive interrupt control register */ 
S2RIC                     DEFINE 0x050
ILVL                      DEFINE 0   
IR                        DEFINE 3    
/* UART0 transmit interrupt control register */ 
S0TIC                     DEFINE 0x051
ILVL                      DEFINE 0   
IR                        DEFINE 3    
/* UART0 receive interrupt control register */ 
S0RIC                     DEFINE 0x052
ILVL                      DEFINE 0   
IR                        DEFINE 3    
/* UART1 transmit interrupt control register */ 
S1TIC                     DEFINE 0x053
ILVL                      DEFINE 0   
IR                        DEFINE 3    
/* UART1 receive interrupt control register */ 
S1RIC                     DEFINE 0x054
ILVL                      DEFINE 0   
IR                        DEFINE 3    
/* Timer A0 interrupt control register */ 
TA0IC                     DEFINE 0x055
ILVL                      DEFINE 0   
IR                        DEFINE 3    
/* Timer A1 interrupt control register */ 
TA1IC                     DEFINE 0x056
ILVL                      DEFINE 0   
IR                        DEFINE 3    
/* Timer A2 interrupt control register */ 
TA2IC                     DEFINE 0x057
ILVL                      DEFINE 0   
IR                        DEFINE 3    
/* Timer A3 interrupt control register */ 
TA3IC                     DEFINE 0x058
ILVL                      DEFINE 0   
IR                        DEFINE 3    
/* Timer A4 interrupt control register */ 
TA4IC                     DEFINE 0x059
ILVL                      DEFINE 0   
IR                        DEFINE 3    
/* Timer B0 interrupt control register */ 
TB0IC                     DEFINE 0x05A
ILVL                      DEFINE 0   
IR                        DEFINE 3    
/* Timer B1 interrupt control register */ 
TB1IC                     DEFINE 0x05B
ILVL                      DEFINE 0   
IR                        DEFINE 3    
/* Timer B2 interrupt control register */ 
TB2IC                     DEFINE 0x05C
ILVL                      DEFINE 0   
IR                        DEFINE 3    
/* Interrupt 0 interrupt control register */ 
INT0IC                    DEFINE 0x05D
ILVL                      DEFINE 0   
IR                        DEFINE 3   
POL                       DEFINE 4    
/* Interrupt 1 interrupt control register */ 
INT1IC                    DEFINE 0x05E
ILVL                      DEFINE 0   
IR                        DEFINE 3   
POL                       DEFINE 4    
/* Interrupt 2 interrupt control register */ 
INT2IC                    DEFINE 0x05F
ILVL                      DEFINE 0   
IR                        DEFINE 3   
POL                       DEFINE 4    
/* Address match interrupt register 2 (low) */ 
RMAD20                    DEFINE 0x1B8 
/* Address match interrupt register 2 (mid) */ 
RMAD21                    DEFINE 0x1B9 
/* Address match interrupt register 2 (high) */ 
RMAD22                    DEFINE 0x1BA 
/* Address match interrupt enable register 2 */ 
AIER2                     DEFINE 0x1BB 
/* Address match interrupt register 2 (low) */ 
RMAD30                    DEFINE 0x1BC 
/* Address match interrupt register 2 (mid) */ 
RMAD31                    DEFINE 0x1BD 
/* Address match interrupt register 2 (high) */ 
RMAD32                    DEFINE 0x1BE 
/* Interrupt cause select register 2 */ 
IFSR2A                    DEFINE 0x35E 
/* Interrupt cause select register */ 
IFSR                      DEFINE 0x35F 

/*-------------------------------------------------------------------------
 *   DMA Registers
 *-------------------------------------------------------------------------*/
 
/* DMA0 source pointer (low) */ 
SAR00                     DEFINE 0x020 
/* DMA0 source pointer (mid) */ 
SAR01                     DEFINE 0x021 
/* DMA0 source pointer (high) */ 
SAR02                     DEFINE 0x022 
/* DMA0 destination pointer (low) */ 
DAR00                     DEFINE 0x024 
/* DMA0 destination pointer (mid) */ 
DAR01                     DEFINE 0x025 
/* DMA0 destination pointer (high) */ 
DAR02                     DEFINE 0x026 
/* DMA0 transfer counter */ 
TCR0                      DEFINE 0x028 
/* DMA0 transfer counter (low) */ 
TCR00                     DEFINE 0x028 
/* DMA0 transfer counter (high) */ 
TCR01                     DEFINE 0x029 
/* DMA0 control register */ 
DM0CON                    DEFINE 0x02C
DMBIT_DM0CON              DEFINE 0   
DMASL_DM0CON              DEFINE 1   
DMAS_DM0CON               DEFINE 2   
DMAE_DM0CON               DEFINE 3   
DSD_DM0CON                DEFINE 4   
DAD_DM0CON                DEFINE 5    
/* DMA1 source pointer (low) */ 
SAR10                     DEFINE 0x030 
/* DMA1 source pointer (mid) */ 
SAR11                     DEFINE 0x031 
/* DMA1 source pointer (high) */ 
SAR12                     DEFINE 0x032 
/* DMA1 destination pointer (low) */ 
DAR10                     DEFINE 0x034 
/* DMA1 destination pointer (mid) */ 
DAR11                     DEFINE 0x035 
/* DMA1 destination pointer (high) */ 
DAR12                     DEFINE 0x036 
/* DMA1 transfer counter */ 
TCR1                      DEFINE 0x038 
/* DMA1 transfer counter (low) */ 
TCR10                     DEFINE 0x038 
/* DMA1 transfer counter (high) */ 
TCR11                     DEFINE 0x039 
/* DMA1 control register */ 
DM1CON                    DEFINE 0x03C
DMBIT_DM1CON              DEFINE 0   
DMASL_DM1CON              DEFINE 1   
DMAS_DM1CON               DEFINE 2   
DMAE_DM1CON               DEFINE 3   
DSD_DM1CON                DEFINE 4   
DAD_DM1CON                DEFINE 5    
/* DMA0 cause selection */ 
DM0SL                     DEFINE 0x3B8 
/* DMA1 cause selection */ 
DM1SL                     DEFINE 0x3BA 

/*-------------------------------------------------------------------------
 *   Timer Registers
 *-------------------------------------------------------------------------*/
 
/* Timer A/B count start flags */ 
TABSR                     DEFINE 0x380
TA0S                      DEFINE 0   
TA1S                      DEFINE 1   
TA2S                      DEFINE 2   
TA3S                      DEFINE 3   
TA4S                      DEFINE 4   
TB0S                      DEFINE 5   
TB1S                      DEFINE 6   
TB2S                      DEFINE 7    
/* Clock prescaler reset flag */ 
CPSRF                     DEFINE 0x381 
CPSR                      DEFINE 7    
/* One-shot start flagl */ 
ONSF                      DEFINE 0x382
TA0OS                     DEFINE 0   
TA1OS                     DEFINE 1   
TA2OS                     DEFINE 2   
TA3OS                     DEFINE 3   
TA4OS                     DEFINE 4   
ZIE                       DEFINE 5   
TA0TGL                    DEFINE 6   
TA0TGH                    DEFINE 7    
/* Trigger select register */ 
TRGSR                     DEFINE 0x383
TA1TGL                    DEFINE 0   
TA1TGH                    DEFINE 1   
TA2TGL                    DEFINE 2   
TA2TGH                    DEFINE 3   
TA3TGL                    DEFINE 4   
TA3TGH                    DEFINE 5   
TA4TGL                    DEFINE 6   
TA4TGH                    DEFINE 7    
/* Up- down-count selection flag */ 
UDF                       DEFINE 0x384
TA0UD                     DEFINE 0   
TA1UD                     DEFINE 1   
TA2UD                     DEFINE 2   
TA3UD                     DEFINE 3   
TA4UD                     DEFINE 4   
TA2P                      DEFINE 5   
TA3P                      DEFINE 6   
TA4P                      DEFINE 7    
/* Timer A0 */ 
TA0                       DEFINE 0x386 
/* Timer A0 (low byte) */ 
TA0L                      DEFINE 0x386 
/* Timer A0 (high byte) */ 
TA0H                      DEFINE 0x387 
/* Timer A1 */ 
TA1                       DEFINE 0x388 
/* Timer A1 (low byte) */ 
TA1L                      DEFINE 0x388 
/* Timer A1 (high byte) */ 
TA1H                      DEFINE 0x389 
/* Timer A2 */ 
TA2                       DEFINE 0x38A 
/* Timer A2 (low byte) */ 
TA2L                      DEFINE 0x38A 
/* Timer A2 (high byte) */ 
TA2H                      DEFINE 0x38B 
/* Timer A3 */ 
TA3                       DEFINE 0x38C 
/* Timer A3 (low byte) */ 
TA3L                      DEFINE 0x38C 
/* Timer A3 (high byte) */ 
TA3H                      DEFINE 0x38D 
/* Timer A4 */ 
TA4                       DEFINE 0x38E 
/* Timer A4 (low byte) */ 
TA4L                      DEFINE 0x38E 
/* Timer A4 (high byte) */ 
TA4H                      DEFINE 0x38F 
/* Timer B0 */ 
TB0                       DEFINE 0x390 
/* Timer B0 (low byte) */ 
TB0L                      DEFINE 0x390 
/* Timer B0 (high byte) */ 
TB0H                      DEFINE 0x391 
/* Timer B1 */ 
TB1                       DEFINE 0x392 
/* Timer B1 (low byte) */ 
TB1L                      DEFINE 0x392 
/* Timer B1 (high byte) */ 
TB1H                      DEFINE 0x393 
/* Timer B2 */ 
TB2                       DEFINE 0x394 
/* Timer B2 (low byte) */ 
TB2L                      DEFINE 0x394 
/* Timer B2 (high byte) */ 
TB2H                      DEFINE 0x395 
/* Timer A0 mode register */ 
TA0MR                     DEFINE 0x396
TMOD0_TA0MR               DEFINE 0   
TMOD1_TA0MR               DEFINE 1   
MR0_TA0MR                 DEFINE 2   
MR1_TA0MR                 DEFINE 3   
MR2_TA0MR                 DEFINE 4   
MR3_TA0MR                 DEFINE 5   
TCK0_TA0MR                DEFINE 6   
TCK1_TA0MR                DEFINE 7    
/* Timer A1 mode register */ 
TA1MR                     DEFINE 0x397
TMOD0_TA1MR               DEFINE 0   
TMOD1_TA1MR               DEFINE 1   
MR0_TA1MR                 DEFINE 2   
MR1_TA1MR                 DEFINE 3   
MR2_TA1MR                 DEFINE 4   
MR3_TA1MR                 DEFINE 5   
TCK0_TA1MR                DEFINE 6   
TCK1_TA1MR                DEFINE 7    
/* Timer A2 mode register */ 
TA2MR                     DEFINE 0x398
TMOD0_TA2MR               DEFINE 0   
TMOD1_TA2MR               DEFINE 1   
MR0_TA2MR                 DEFINE 2   
MR1_TA2MR                 DEFINE 3   
MR2_TA2MR                 DEFINE 4   
MR3_TA2MR                 DEFINE 5   
TCK0_TA2MR                DEFINE 6   
TCK1_TA2MR                DEFINE 7    
/* Timer A3 mode register */ 
TA3MR                     DEFINE 0x399
TMOD0_TA3MR               DEFINE 0   
TMOD1_TA3MR               DEFINE 1   
MR0_TA3MR                 DEFINE 2   
MR1_TA3MR                 DEFINE 3   
MR2_TA3MR                 DEFINE 4   
MR3_TA3MR                 DEFINE 5   
TCK0_TA3MR                DEFINE 6   
TCK1_TA3MR                DEFINE 7    
/* Timer A4 mode register */ 
TA4MR                     DEFINE 0x39A
TMOD0_TA4MR               DEFINE 0   
TMOD1_TA4MR               DEFINE 1   
MR0_TA4MR                 DEFINE 2   
MR1_TA4MR                 DEFINE 3   
MR2_TA4MR                 DEFINE 4   
MR3_TA4MR                 DEFINE 5   
TCK0_TA4MR                DEFINE 6   
TCK1_TA4MR                DEFINE 7    
/* Timer B0 mode register */ 
TB0MR                     DEFINE 0x39B
TMOD0_TB0MR               DEFINE 0   
TMOD1_TB0MR               DEFINE 1   
MR0_TB0MR                 DEFINE 2   
MR1_TB0MR                 DEFINE 3   
MR2_TB0MR                 DEFINE 4   
MR3_TB0MR                 DEFINE 5   
TCK0_TB0MR                DEFINE 6   
TCK1_TB0MR                DEFINE 7    
/* Timer B1 mode register */ 
TB1MR                     DEFINE 0x39C
TMOD0_TB1MR               DEFINE 0   
TMOD1_TB1MR               DEFINE 1   
MR0_TB1MR                 DEFINE 2   
MR1_TB1MR                 DEFINE 3    
MR3_TB1MR                 DEFINE 5   
TCK0_TB1MR                DEFINE 6   
TCK1_TB1MR                DEFINE 7    
/* Timer B2 mode register */ 
TB2MR                     DEFINE 0x39D
TMOD0_TB2MR               DEFINE 0   
TMOD1_TB2MR               DEFINE 1   
MR0_TB2MR                 DEFINE 2   
MR1_TB2MR                 DEFINE 3   
                          DEFINE 4   
MR3_TB2MR                 DEFINE 5   
TCK0_TB2MR                DEFINE 6   
TCK1_TB2MR                DEFINE 7    
/* Timer B2 special mode register */ 
TB2SC                     DEFINE 0x39E
PWCON                     DEFINE 0   
IVPCR1                    DEFINE 1    
/* Timer B3,4,5 count start flag */ 
TBSR                      DEFINE 0x340 
TB3S                      DEFINE 5   
TB4S                      DEFINE 6   
TB5S                      DEFINE 7    
/* Timer B3 */ 
TB3                       DEFINE 0x350 
/* Timer B3 (low byte) */ 
TB3L                      DEFINE 0x350 
/* Timer B3 (high byte) */ 
TB3H                      DEFINE 0x351 
/* Timer B4 */ 
TB4                       DEFINE 0x352 
/* Timer B4 (low byte) */ 
TB4L                      DEFINE 0x352 
/* Timer B4 (high byte) */ 
TB4H                      DEFINE 0x353 
/* Timer B5 */ 
TB5                       DEFINE 0x354 
/* Timer B5 (low byte) */ 
TB5L                      DEFINE 0x354 
/* Timer B5 (high byte) */ 
TB5H                      DEFINE 0x355 
/* Timer B3 mode register */ 
TB3MR                     DEFINE 0x35B
TMOD0_TB3MR               DEFINE 0   
TMOD1_TB3MR               DEFINE 1   
MR0_TB3MR                 DEFINE 2   
MR1_TB3MR                 DEFINE 3   
MR2_TB3MR                 DEFINE 4   
MR3_TB3MR                 DEFINE 5   
TCK0_TB3MR                DEFINE 6   
TCK1_TB3MR                DEFINE 7    
/* Timer B4 mode register */ 
TB4MR                     DEFINE 0x35C
TMOD0_TB4MR               DEFINE 0   
TMOD1_TB4MR               DEFINE 1   
MR0_TB4MR                 DEFINE 2   
MR1_TB4MR                 DEFINE 3    
MR3_TB4MR                 DEFINE 5   
TCK0_TB4MR                DEFINE 6   
TCK1_TB4MR                DEFINE 7    
/* Timer B5 mode register */ 
TB5MR                     DEFINE 0x35D
TMOD0_TB5MR               DEFINE 0   
TMOD1_TB5MR               DEFINE 1   
MR0_TB5MR                 DEFINE 2   
MR1_TB5MR                 DEFINE 3    
MR3_TB5MR                 DEFINE 5   
TCK0_TB5MR                DEFINE 6   
TCK1_TB5MR                DEFINE 7    
/* Timer A1-1 register */ 
TA11                      DEFINE 0x342 
/* Timer A1-1 register (low byte) */ 
TA11L                     DEFINE 0x342 
/* Timer A1-1 register (high byte) */ 
TA11H                     DEFINE 0x343 
/* Timer A2-1 register */ 
TA21                      DEFINE 0x344 
/* Timer A2-1 register (low byte) */ 
TA21L                     DEFINE 0x344 
/* Timer A2-1 register (high byte) */ 
TA21H                     DEFINE 0x345 
/* Timer A4-1 register */ 
TA41                      DEFINE 0x346 
/* Timer A4-1 register (low byte) */ 
TA41L                     DEFINE 0x346 
/* Timer A4-1 register (high byte) */ 
TA41H                     DEFINE 0x347 
/* Three-phase PWM control register 0 */ 
INVC0                     DEFINE 0x348
INV00                     DEFINE 0   
INV01                     DEFINE 1   
INV02                     DEFINE 2   
INV03                     DEFINE 3   
INV04                     DEFINE 4   
INV05                     DEFINE 5   
INV06                     DEFINE 6   
INV07                     DEFINE 7    
/* Three-phase PWM control register 1 */ 
INVC1                     DEFINE 0x349
INV10                     DEFINE 0   
INV11                     DEFINE 1   
INV12                     DEFINE 2   
INV13                     DEFINE 3   
INV14                     DEFINE 4   
INV15                     DEFINE 5   
INV16                     DEFINE 6     
/* Three-phase output buffer register 0 */ 
IDB0                      DEFINE 0x34A
DU0                       DEFINE 0   
DUB0                      DEFINE 1   
DV0                       DEFINE 2   
DVB0                      DEFINE 3   
DW0                       DEFINE 4   
DWB0                      DEFINE 5     
/* Three-phase output buffer register 1 */ 
IDB1                      DEFINE 0x34B
DU1                       DEFINE 0   
DUB1                      DEFINE 1   
DV1                       DEFINE 2   
DVB1                      DEFINE 3   
DW1                       DEFINE 4   
DWB1                      DEFINE 5     
/* Dead time timer */ 
DTT                       DEFINE 0x34C 
/* Timer B2 interrupt occurence frequency set coutnter */ 
ICTB2                     DEFINE 0x34D 

/*-------------------------------------------------------------------------
 *   UART Registers
 *-------------------------------------------------------------------------*/
 
/* UART 0 transmit/receive mode register */ 
U0MR                      DEFINE 0x3A0
SMD0_U0MR                 DEFINE 0   
SMD1_U0MR                 DEFINE 1   
SMD2_U0MR                 DEFINE 2   
CKDIR_U0MR                DEFINE 3   
STPS_U0MR                 DEFINE 4   
PRY_U0MR                  DEFINE 5   
PRYE_U0MR                 DEFINE 6   
IOPOL_U0MR                DEFINE 7    
/* UART 0 baud rate generator */ 
U0BRG                     DEFINE 0x3A1 
/* UART 0 transmit buffer */ 
U0TB                      DEFINE 0x3A2 
/* UART 0 transmit buffer (low byte) */ 
U0TBL                     DEFINE 0x3A2 
/* UART 0 transmit buffer (high byte) */ 
U0TBH                     DEFINE 0x3A3 
/* UART 0 transmit/receive control register */ 
U0C                       DEFINE 0x3A4 
/* UART 0 transmit/receive control register 0 */ 
U0C0                      DEFINE 0x3A4
CLK0_U0C0                 DEFINE 0   
CLK1_U0C0                 DEFINE 1   
CRS_U0C0                  DEFINE 2   
TXEPT_U0C0                DEFINE 3   
CRD_U0C0                  DEFINE 4   
NCH_U0C0                  DEFINE 5   
CKPOL_U0C0                DEFINE 6   
UFORM_U0C0                DEFINE 7    
/* UART 0 transmit/receive control register 1 */ 
U0C1                      DEFINE 0x3A5
TE_U0C1                   DEFINE 0   
TI_U0C1                   DEFINE 1   
RE_U0C1                   DEFINE 2   
RI_U0C1                   DEFINE 3     
U0LCH                     DEFINE 6   
U0ERE                     DEFINE 7    
/* UART 0 receive buffer */ 
U0RB                      DEFINE 0x3A6 
/* UART 0 receive buffer (low byte) */ 
U0RBL                     DEFINE 0x3A6 
/* UART 0 receive buffer (high byte) */ 
U0RBH                     DEFINE 0x3A7 
/* UART 1 transmit/receive mode register */ 
U1MR                      DEFINE 0x3A8
SMD0_U1MR                 DEFINE 0   
SMD1_U1MR                 DEFINE 1   
SMD2_U1MR                 DEFINE 2   
CKDIR_U1MR                DEFINE 3   
STPS_U1MR                 DEFINE 4   
PRY_U1MR                  DEFINE 5   
PRYE_U1MR                 DEFINE 6   
IOPOL_U1MR                DEFINE 7    
/* UART 1 baud rate generator */ 
U1BRG                     DEFINE 0x3A9 
/* UART 1 transmit buffer */ 
U1TB                      DEFINE 0x3AA 
/* UART 1 transmit buffer (low byte) */ 
U1TBL                     DEFINE 0x3AA 
/* UART 1 tfransmit buffer (high byte) */ 
U1TBH                     DEFINE 0x3AB 
/* UART 1 transmit/receive control register */ 
U1C                       DEFINE 0x3AC 
/* UART 1 transmit/receive control register 0 */ 
U1C0                      DEFINE 0x3AC
CLK0_U1C0                 DEFINE 0   
CLK1_U1C0                 DEFINE 1   
CRS_U1C0                  DEFINE 2   
TXEPT_U1C0                DEFINE 3   
CRD_U1C0                  DEFINE 4   
NCH_U1C0                  DEFINE 5   
CKPOL_U1C0                DEFINE 6   
UFORM_U1C0                DEFINE 7    
/* UART 1 transmit/receive control register 1 */ 
U1C1                      DEFINE 0x3AD
TE_U1C1                   DEFINE 0   
TI_U1C1                   DEFINE 1   
RE_U1C1                   DEFINE 2   
RI_U1C1                   DEFINE 3     
U1LCH                     DEFINE 6   
U1ERE                     DEFINE 7    
/* UART 1 receive buffer */ 
U1RB                      DEFINE 0x3AE 
/* UART 1 receive buffer (low byte) */ 
U1RBL                     DEFINE 0x3AE 
/* UART 1 receive buffer (high byte) */ 
U1RBH                     DEFINE 0x3AF 
/* UART transmit/receive control register 2 */ 
UCON                      DEFINE 0x3B0
U0IRS                     DEFINE 0   
U1IRS                     DEFINE 1   
U0RRM                     DEFINE 2   
U1RRM                     DEFINE 3   
CLKMD0                    DEFINE 4   
CLKMD1                    DEFINE 5   
RCSP                      DEFINE 6    
/* SI/O3 transmit/receive register */ 
S3TRR                     DEFINE 0x360 
/* SI/O3 control register */ 
S3C                       DEFINE 0x362
SM30                      DEFINE 0   
SM31                      DEFINE 1   
SM32                      DEFINE 2   
SM33                      DEFINE 3   
SM34                      DEFINE 4   
SM35                      DEFINE 5   
SM36                      DEFINE 6   
SM37                      DEFINE 7    
/* SI/O3 bit rate generator */ 
S3BRG                     DEFINE 0x363 
/* SI/O4 transmit/reveive register */ 
S4TRR                     DEFINE 0x364 
/* SI/O4 control register */ 
S4C                       DEFINE 0x366
SM40                      DEFINE 0   
SM41                      DEFINE 1   
SM42                      DEFINE 2   
SM43                      DEFINE 3   
SM44                      DEFINE 4   
SM45                      DEFINE 5   
SM46                      DEFINE 6   
SM47                      DEFINE 7    
/* SI/O4 bit rate generator */ 
S4BRG                     DEFINE 0x367 
/* UART 0 special mode register 4 */ 
U0SMR4                    DEFINE 0x36C
STAREQ_U0SMR4             DEFINE 0   
RSTAREQ_U0SMR4            DEFINE 1   
STPREQ_U0SMR4             DEFINE 2   
STSPSEL_U0SMR4            DEFINE 3   
ACKD_U0SMR4               DEFINE 4   
ACKC_U0SMR4               DEFINE 5   
SCLHI_U0SMR4              DEFINE 6   
SWC9_U0SMR4               DEFINE 7    
/* UART 0 special mode register 3 */ 
U0SMR3                    DEFINE 0x36D 
CKPH_U0SMR3               DEFINE 1    
NODC_U0SMR3               DEFINE 3    
DL0_U0SMR3                DEFINE 5   
DL1_U0SMR3                DEFINE 6   
DL2_U0SMR3                DEFINE 7    
/* UART 0 special mode register 2 */ 
U0SMR2                    DEFINE 0x36E
IICM2_U0SMR2              DEFINE 0   
CSC_U0SMR2                DEFINE 1   
SWC_U0SMR2                DEFINE 2   
ALS_U0SMR2                DEFINE 3   
STAC_U0SMR2               DEFINE 4   
SWC2_U0SMR2               DEFINE 5   
SDHI_U0SMR2               DEFINE 6    
/* UART 0 special mode register */ 
U0SMR                     DEFINE 0x36F
IICM_U0SMR                DEFINE 0   
ABC_U0SMR                 DEFINE 1   
BBS_U0SMR                 DEFINE 2   
LSYN_U0SMR                DEFINE 3   
ABSCS_U0SMR               DEFINE 4   
ACSE_U0SMR                DEFINE 5   
SSS_U0SMR                 DEFINE 6    
/* UART 1 special mode register 4 */ 
U1SMR4                    DEFINE 0x370
STAREQ_U1SMR4             DEFINE 0   
RSTAREQ_U1SMR4            DEFINE 1   
STPREQ_U1SMR4             DEFINE 2   
STSPSEL_U1SMR4            DEFINE 3   
ACKD_U1SMR4               DEFINE 4   
ACKC_U1SMR4               DEFINE 5   
SCLHI_U1SMR4              DEFINE 6   
SWC9_U1SMR4               DEFINE 7    
/* UART 1 special mode register 3 */ 
U1SMR3                    DEFINE 0x371 
CKPH_U1SMR3               DEFINE 1    
NODC_U1SMR3               DEFINE 3    
DL0_U1SMR3                DEFINE 5   
DL1_U1SMR3                DEFINE 6   
DL2_U1SMR3                DEFINE 7    
/* UART 1 special mode register 2 */ 
U1SMR2                    DEFINE 0x372
IICM2_U1SMR2              DEFINE 0   
CSC_U1SMR2                DEFINE 1   
SWC_U1SMR2                DEFINE 2   
ALS_U1SMR2                DEFINE 3   
STAC_U1SMR2               DEFINE 4   
SWC2_U1SMR2               DEFINE 5   
SDHI_U1SMR2               DEFINE 6    
/* UART 1 special mode register */ 
U1SMR                     DEFINE 0x373
IICM_U1SMR                DEFINE 0   
ABC_U1SMR                 DEFINE 1   
BBS_U1SMR                 DEFINE 2   
LSYN_U1SMR                DEFINE 3   
ABSCS_U1SMR               DEFINE 4   
ACSE_U1SMR                DEFINE 5   
SSS_U1SMR                 DEFINE 6    
/* UART 2 special mode register 4 */ 
U2SMR4                    DEFINE 0x374
STAREQ_U2SMR4             DEFINE 0   
RSTAREQ_U2SMR4            DEFINE 1   
STPREQ_U2SMR4             DEFINE 2   
STSPSEL_U2SMR4            DEFINE 3   
ACKD_U2SMR4               DEFINE 4   
ACKC_U2SMR4               DEFINE 5   
SCLHI_U2SMR4              DEFINE 6   
SWC9_U2SMR4               DEFINE 7    
/* UART 2 special mode register 3 */ 
U2SMR3                    DEFINE 0x375 
CKPH_U2SMR3               DEFINE 1    
NODC_U2SMR3               DEFINE 3    
DL0_U2SMR3                DEFINE 5   
DL1_U2SMR3                DEFINE 6   
DL2_U2SMR3                DEFINE 7    
/* UART 2 special mode register 2 */ 
U2SMR2                    DEFINE 0x376
IICM2_U2SMR2              DEFINE 0   
CSC_U2SMR2                DEFINE 1   
SWC_U2SMR2                DEFINE 2   
ALS_U2SMR2                DEFINE 3   
STAC_U2SMR2               DEFINE 4   
SWC2_U2SMR2               DEFINE 5   
SDHI_U2SMR2               DEFINE 6    
/* UART 2 special mode register */ 
U2SMR                     DEFINE 0x377
IICM_U2SMR                DEFINE 0   
ABC_U2SMR                 DEFINE 1   
BBS_U2SMR                 DEFINE 2   
LSYN_U2SMR                DEFINE 3   
ABSCS_U2SMR               DEFINE 4   
ACSE_U2SMR                DEFINE 5   
SSS_U2SMR                 DEFINE 6    
/* UART 2 transmit/receive mode register */ 
U2MR                      DEFINE 0x378
SMD0_U2MR                 DEFINE 0   
SMD1_U2MR                 DEFINE 1   
SMD2_U2MR                 DEFINE 2   
CKDIR_U2MR                DEFINE 3   
STPS_U2MR                 DEFINE 4   
PRY_U2MR                  DEFINE 5   
PRYE_U2MR                 DEFINE 6   
IOPOL_U2MR                DEFINE 7    
/* UART 2 bit rate generator */ 
U2BRG                     DEFINE 0x379 
/* UART 2 transmit buffer register */ 
U2TB                      DEFINE 0x37A 
/* UART 2 transmit buffer register (low byte) */ 
U2TBL                     DEFINE 0x37A 
/* UART 2 transmit buffer register (high byte) */ 
U2TBH                     DEFINE 0x37B 
/* UART 2 transmit/receive control register 0 */ 
U2C0                      DEFINE 0x37C
CLK0_U2C0                 DEFINE 0   
CLK1_U2C0                 DEFINE 1   
CRS_U2C0                  DEFINE 2   
TXEPT_U2C0                DEFINE 3   
CRD_U2C0                  DEFINE 4   
NCH_U2C0                  DEFINE 5   
CKPOL_U2C0                DEFINE 6   
UFORM_U2C0                DEFINE 7    
/* UART 2 transmit/receive control register 1 */ 
U2C1                      DEFINE 0x37D
TE_U2C1                   DEFINE 0   
TI_U2C1                   DEFINE 1   
RE_U2C1                   DEFINE 2   
RI_U2C1                   DEFINE 3   
U2IRS                     DEFINE 4   
U2RRM                     DEFINE 5   
U2LCH                     DEFINE 6   
U2ERE                     DEFINE 7    
/* UART 2 receive buffer register */ 
U2RB                      DEFINE 0x37E 
/* UART 2 receive buffer register (low byte) */ 
U2RBL                     DEFINE 0x37E 
/* UART 2 receive buffer register (high byte) */ 
U2RBH                     DEFINE 0x37F 

/*-------------------------------------------------------------------------
 *   Flash control register
 *-------------------------------------------------------------------------*/
 
/* Flash identification register */ 
FIDR                      DEFINE 0x1B4 
/* Flash memory control register 1 */ 
FMR1                      DEFINE 0x1B5 
FMR11                     DEFINE 1    
FMR06                     DEFINE 6    
/* Flash memory control register 0 */ 
FMR0                      DEFINE 0x1B7
FMR00                     DEFINE 0   
FMR01                     DEFINE 1   
FMR02                     DEFINE 2   
FMSTP                     DEFINE 3    
FMR05                     DEFINE 5   
FMR06                     DEFINE 6   
FMR07                     DEFINE 7    

/*-------------------------------------------------------------------------
 *   CRC register
 *-------------------------------------------------------------------------*/
 
/* CRC data register */ 
CRCD                      DEFINE 0x3BC 
/* CRC data register (low byte) */ 
CRCDL                     DEFINE 0x3BC 
/* CRC data register (high byte) */ 
CRCDH                     DEFINE 0x3BD 
/* CRC input register */ 
CRCIN                     DEFINE 0x3BE 

/*-------------------------------------------------------------------------
 *   A/D Converter
 *-------------------------------------------------------------------------*/
 
/* A/D register 0 */ 
AD0                       DEFINE 0x3C0 
/* A/D register 0 (low byte) */ 
AD0L                      DEFINE 0x3C0 
/* A/D register 0 (high byte) */ 
AD0H                      DEFINE 0x3C1 
/* A/D register 1 */ 
AD1                       DEFINE 0x3C2 
/* A/D register 1 (low byte) */ 
AD1L                      DEFINE 0x3C2 
/* A/D register 1 (high byte) */ 
AD1H                      DEFINE 0x3C3 
/* A/D register 2 */ 
AD2                       DEFINE 0x3C4 
/* A/D register 2 (low byte) */ 
AD2L                      DEFINE 0x3C4 
/* A/D register 2 (high byte) */ 
AD2H                      DEFINE 0x3C5 
/* A/D register 3 */ 
AD3                       DEFINE 0x3C6 
/* A/D register 3 (low byte) */ 
AD3L                      DEFINE 0x3C6 
/* A/D register 3 (high byte) */ 
AD3H                      DEFINE 0x3C7 
/* A/D register 4 */ 
AD4                       DEFINE 0x3C8 
/* A/D register 4 (low byte) */ 
AD4L                      DEFINE 0x3C8 
/* A/D register 4 (high byte) */ 
AD4H                      DEFINE 0x3C9 
/* A/D register 5 */ 
AD5                       DEFINE 0x3CA 
/* A/D register 5 (low byte) */ 
AD5L                      DEFINE 0x3CA 
/* A/D register 5 (high byte) */ 
AD5H                      DEFINE 0x3CB 
/* A/D register 6 */ 
AD6                       DEFINE 0x3CC 
/* A/D register 6 (low byte) */ 
AD6L                      DEFINE 0x3CC 
/* A/D register 6 (high byte) */ 
AD6H                      DEFINE 0x3CD 
/* A/D register 7 */ 
AD7                       DEFINE 0x3CE 
/* A/D register 7 (low byte) */ 
AD7L                      DEFINE 0x3CE 
/* A/D register 7 (high byte) */ 
AD7H                      DEFINE 0x3CF 
/* A/D control register 2 */ 
ADCON2                    DEFINE 0x3D4
SMP                       DEFINE 0   
ADGSEL0                   DEFINE 1   
ADGSEL1                   DEFINE 2    
CKS2                      DEFINE 4    
/* A/D control register 0 */ 
ADCON0                    DEFINE 0x3D6
CH0                       DEFINE 0   
CH1                       DEFINE 1   
CH2                       DEFINE 2   
MD0                       DEFINE 3   
MD1                       DEFINE 4   
TRG                       DEFINE 5   
ADST                      DEFINE 6   
CKS0                      DEFINE 7    
/* A/D control register 1 */ 
ADCON1                    DEFINE 0x3D7
SCAN0                     DEFINE 0   
SCAN1                     DEFINE 1   
MD2                       DEFINE 2   
BITS                      DEFINE 3   
CKS1                      DEFINE 4   
VCUT                      DEFINE 5   
OPA0                      DEFINE 6   
OPA1                      DEFINE 7    

/*-------------------------------------------------------------------------
 *   D-A Converter
 *-------------------------------------------------------------------------*/
 
/* D-A register 0 */ 
DA0                       DEFINE 0x3D8 
/* D-A register 1 */ 
DA1                       DEFINE 0x3DA 
/* D-A control register */ 
DACON                     DEFINE 0x3DC
DA0E                      DEFINE 0   
DA1E                      DEFINE 1    

/*-------------------------------------------------------------------------
 *   Power supply
 *-------------------------------------------------------------------------*/
 
/* Power supply detection register 1 */ 
VCR1                      DEFINE 0x019   
VC13                      DEFINE 3    
/* Power supply detection register 2 */ 
VCR2                      DEFINE 0x01A     
VC25                      DEFINE 5   
VC26                      DEFINE 6   
VC27                      DEFINE 7    
/* Power supply down detection register */ 
D4INT                     DEFINE 0x01F
D40                       DEFINE 0   
D41                       DEFINE 1   
D42                       DEFINE 2   
D43                       DEFINE 3   
DF0                       DEFINE 4   
DF1                       DEFINE 5    

/*-------------------------------------------------------------------------
 *   Port Registers
 *-------------------------------------------------------------------------*/
 
/* Port P14 register */ 
PC14                      DEFINE 0x3DE
P140                      DEFINE 0   
P141                      DEFINE 1     
PD140                     DEFINE 4   
PD141                     DEFINE 5    
/* Pull-up register 3 */ 
PUR3                      DEFINE 0x3DF
PU30                      DEFINE 0   
PU31                      DEFINE 1   
PU32                      DEFINE 2   
PU33                      DEFINE 3   
PU34                      DEFINE 4   
PU35                      DEFINE 5   
PU36                      DEFINE 6   
PU37                      DEFINE 7    
/* Port P0 register */ 
P0                        DEFINE 0x3E0
P0_0                      DEFINE 0   
P0_1                      DEFINE 1   
P0_2                      DEFINE 2   
P0_3                      DEFINE 3   
P0_4                      DEFINE 4   
P0_5                      DEFINE 5   
P0_6                      DEFINE 6   
P0_7                      DEFINE 7    
/* Port P1 register */ 
P1                        DEFINE 0x3E1
P1_0                      DEFINE 0   
P1_1                      DEFINE 1   
P1_2                      DEFINE 2   
P1_3                      DEFINE 3   
P1_4                      DEFINE 4   
P1_5                      DEFINE 5   
P1_6                      DEFINE 6   
P1_7                      DEFINE 7    
/* Port P0 and P1 register */ 
P01                       DEFINE 0x3E0 
/* Port P0 direction register */ 
PD0                       DEFINE 0x3E2
PD0_0                     DEFINE 0   
PD0_1                     DEFINE 1   
PD0_2                     DEFINE 2   
PD0_3                     DEFINE 3   
PD0_4                     DEFINE 4   
PD0_5                     DEFINE 5   
PD0_6                     DEFINE 6   
PD0_7                     DEFINE 7    
/* Port P1 direction register */ 
PD1                       DEFINE 0x3E3
PD1_0                     DEFINE 0   
PD1_1                     DEFINE 1   
PD1_2                     DEFINE 2   
PD1_3                     DEFINE 3   
PD1_4                     DEFINE 4   
PD1_5                     DEFINE 5   
PD1_6                     DEFINE 6   
PD1_7                     DEFINE 7    
/* Port P0 and P1 direction register */ 
PD01                      DEFINE 0x3E2 
/* Port P2 register */ 
P2                        DEFINE 0x3E4
P2_0                      DEFINE 0   
P2_1                      DEFINE 1   
P2_2                      DEFINE 2   
P2_3                      DEFINE 3   
P2_4                      DEFINE 4   
P2_5                      DEFINE 5   
P2_6                      DEFINE 6   
P2_7                      DEFINE 7    
/* Port P3 register */ 
P3                        DEFINE 0x3E5
P3_0                      DEFINE 0   
P3_1                      DEFINE 1   
P3_2                      DEFINE 2   
P3_3                      DEFINE 3   
P3_4                      DEFINE 4   
P3_5                      DEFINE 5   
P3_6                      DEFINE 6   
P3_7                      DEFINE 7    
/* Port P2 and P3 register */ 
P23                       DEFINE 0x3E4 
/* Port P2 direction register */ 
PD2                       DEFINE 0x3E6
PD2_0                     DEFINE 0   
PD2_1                     DEFINE 1   
PD2_2                     DEFINE 2   
PD2_3                     DEFINE 3   
PD2_4                     DEFINE 4   
PD2_5                     DEFINE 5   
PD2_6                     DEFINE 6   
PD2_7                     DEFINE 7    
/* Port P3 direction register */ 
PD3                       DEFINE 0x3E7
PD3_0                     DEFINE 0   
PD3_1                     DEFINE 1   
PD3_2                     DEFINE 2   
PD3_3                     DEFINE 3   
PD3_4                     DEFINE 4   
PD3_5                     DEFINE 5   
PD3_6                     DEFINE 6   
PD3_7                     DEFINE 7    
/* Port P2 and P3 direction register */ 
PD23                      DEFINE 0x3E6 
/* Port P4 register */ 
P4                        DEFINE 0x3E8
P4_0                      DEFINE 0   
P4_1                      DEFINE 1   
P4_2                      DEFINE 2   
P4_3                      DEFINE 3   
P4_4                      DEFINE 4   
P4_5                      DEFINE 5   
P4_6                      DEFINE 6   
P4_7                      DEFINE 7    
/* Port P5 register */ 
P5                        DEFINE 0x3E9
P5_0                      DEFINE 0   
P5_1                      DEFINE 1   
P5_2                      DEFINE 2   
P5_3                      DEFINE 3   
P5_4                      DEFINE 4   
P5_5                      DEFINE 5   
P5_6                      DEFINE 6   
P5_7                      DEFINE 7    
/* Port P4 and P5 register */ 
P45                       DEFINE 0x3E8 
/* Port P4 direction register */ 
PD4                       DEFINE 0x3EA
PD4_0                     DEFINE 0   
PD4_1                     DEFINE 1   
PD4_2                     DEFINE 2   
PD4_3                     DEFINE 3   
PD4_4                     DEFINE 4   
PD4_5                     DEFINE 5   
PD4_6                     DEFINE 6   
PD4_7                     DEFINE 7    
/* Port P5 direction register */ 
PD5                       DEFINE 0x3EB
PD5_0                     DEFINE 0   
PD5_1                     DEFINE 1   
PD5_2                     DEFINE 2   
PD5_3                     DEFINE 3   
PD5_4                     DEFINE 4   
PD5_5                     DEFINE 5   
PD5_6                     DEFINE 6   
PD5_7                     DEFINE 7    
/* Port P4 and P5 direction register */ 
PD45                      DEFINE 0x3EA 
/* Port P6 register */ 
P6                        DEFINE 0x3EC
P6_0                      DEFINE 0   
P6_1                      DEFINE 1   
P6_2                      DEFINE 2   
P6_3                      DEFINE 3   
P6_4                      DEFINE 4   
P6_5                      DEFINE 5   
P6_6                      DEFINE 6   
P6_7                      DEFINE 7    
/* Port P7 register */ 
P7                        DEFINE 0x3ED
P7_0                      DEFINE 0   
P7_1                      DEFINE 1   
P7_2                      DEFINE 2   
P7_3                      DEFINE 3   
P7_4                      DEFINE 4   
P7_5                      DEFINE 5   
P7_6                      DEFINE 6   
P7_7                      DEFINE 7    
/* Port P6 and P7 register */ 
P67                       DEFINE 0x3EC 
/* Port P6 direction register */ 
PD6                       DEFINE 0x3EE
PD6_0                     DEFINE 0   
PD6_1                     DEFINE 1   
PD6_2                     DEFINE 2   
PD6_3                     DEFINE 3   
PD6_4                     DEFINE 4   
PD6_5                     DEFINE 5   
PD6_6                     DEFINE 6   
PD6_7                     DEFINE 7    
/* Port P7 direction register */ 
PD7                       DEFINE 0x3EF
PD7_0                     DEFINE 0   
PD7_1                     DEFINE 1   
PD7_2                     DEFINE 2   
PD7_3                     DEFINE 3   
PD7_4                     DEFINE 4   
PD7_5                     DEFINE 5   
PD7_6                     DEFINE 6   
PD7_7                     DEFINE 7    
/* Port P6 and P7 direction register */ 
PD67                      DEFINE 0x3EE 
/* Port P8 register */ 
P8                        DEFINE 0x3F0
P8_0                      DEFINE 0   
P8_1                      DEFINE 1   
P8_2                      DEFINE 2   
P8_3                      DEFINE 3   
P8_4                      DEFINE 4   
P8_5                      DEFINE 5   
P8_6                      DEFINE 6   
P8_7                      DEFINE 7    
/* Port P9 register */ 
P9                        DEFINE 0x3F1
P9_0                      DEFINE 0   
P9_1                      DEFINE 1   
P9_2                      DEFINE 2   
P9_3                      DEFINE 3   
P9_4                      DEFINE 4   
P9_5                      DEFINE 5   
P9_6                      DEFINE 6   
P9_7                      DEFINE 7    
/* Port P8 and P9 register */ 
P89                       DEFINE 0x3F0 
/* Port P8 direction register */ 
PD8                       DEFINE 0x3F2
PD8_0                     DEFINE 0   
PD8_1                     DEFINE 1   
PD8_2                     DEFINE 2   
PD8_3                     DEFINE 3   
PD8_4                     DEFINE 4    
PD8_6                     DEFINE 6   
PD8_7                     DEFINE 7    
/* Port P9 direction register */ 
PD9                       DEFINE 0x3F3
PD9_0                     DEFINE 0   
PD9_1                     DEFINE 1   
PD9_2                     DEFINE 2   
PD9_3                     DEFINE 3   
PD9_4                     DEFINE 4   
PD9_5                     DEFINE 5   
PD9_6                     DEFINE 6   
PD9_7                     DEFINE 7    
/* Port P8 and P9 direction register */ 
PD89                      DEFINE 0x3F2 
/* Port P10 register */ 
P10                       DEFINE 0x3F4
P10_0                     DEFINE 0   
P10_1                     DEFINE 1   
P10_2                     DEFINE 2   
P10_3                     DEFINE 3   
P10_4                     DEFINE 4   
P10_5                     DEFINE 5   
P10_6                     DEFINE 6   
P10_7                     DEFINE 7    
/* Port P11 register */ 
P11                       DEFINE 0x3F5
P11_0                     DEFINE 0   
P11_1                     DEFINE 1   
P11_2                     DEFINE 2   
P11_3                     DEFINE 3   
P11_4                     DEFINE 4   
P11_5                     DEFINE 5   
P11_6                     DEFINE 6   
P11_7                     DEFINE 7    
/* Port P10 direction register */ 
PD10                      DEFINE 0x3F6
PD10_0                    DEFINE 0   
PD10_1                    DEFINE 1   
PD10_2                    DEFINE 2   
PD10_3                    DEFINE 3   
PD10_4                    DEFINE 4   
PD10_5                    DEFINE 5   
PD10_6                    DEFINE 6   
PD10_7                    DEFINE 7    
/* Port P11 direction register */ 
PD11                      DEFINE 0x3F7
PD11_0                    DEFINE 0   
PD11_1                    DEFINE 1   
PD11_2                    DEFINE 2   
PD11_3                    DEFINE 3   
PD11_4                    DEFINE 4   
PD11_5                    DEFINE 5   
PD11_6                    DEFINE 6   
PD11_7                    DEFINE 7    
/* Port P12 register */ 
P12                       DEFINE 0x3F8
P12_0                     DEFINE 0   
P12_1                     DEFINE 1   
P12_2                     DEFINE 2   
P12_3                     DEFINE 3   
P12_4                     DEFINE 4   
P12_5                     DEFINE 5   
P12_6                     DEFINE 6   
P12_7                     DEFINE 7    
/* Port P13 register */ 
P13                       DEFINE 0x3F9
P13_0                     DEFINE 0   
P13_1                     DEFINE 1   
P13_2                     DEFINE 2   
P13_3                     DEFINE 3   
P13_4                     DEFINE 4   
P13_5                     DEFINE 5   
P13_6                     DEFINE 6   
P13_7                     DEFINE 7    
/* Port P12 direction register */ 
PD12                      DEFINE 0x3FA
PD12_0                    DEFINE 0   
PD12_1                    DEFINE 1   
PD12_2                    DEFINE 2   
PD12_3                    DEFINE 3   
PD12_4                    DEFINE 4   
PD12_5                    DEFINE 5   
PD12_6                    DEFINE 6   
PD12_7                    DEFINE 7    
/* Port P13 direction register */ 
PD13                      DEFINE 0x3FB
PD13_0                    DEFINE 0   
PD13_1                    DEFINE 1   
PD13_2                    DEFINE 2   
PD13_3                    DEFINE 3   
PD13_4                    DEFINE 4   
PD13_5                    DEFINE 5   
PD13_6                    DEFINE 6   
PD13_7                    DEFINE 7    
/* Port P12 and P13 direction register */ 
PD1213                    DEFINE 0x3FA 
/* Pull-up register 0 */ 
PUR0                      DEFINE 0x3FC
PU00                      DEFINE 0    
/* Pull-up register 1 */ 
PUR1                      DEFINE 0x3FD 
/* Pull-up register 0 and 1 */ 
PUR01                     DEFINE 0x3FC 
/* Pull-up register 2 */ 
PUR2                      DEFINE 0x3FE 
/* Port control register */ 
PCR                       DEFINE 0x3FF 


#endif /* __IAR_SYSTEMS_ASM__*/

/*
        Interrupt Vectors
        For Trap vectors, see intrinsics.h
*/
#define BRK          0x00  /* Vector 0, BRK instruction                            */
#define INT3         0x04  /* Vector 4, External source                            */
#define TMRB5        0x05  /* Vector 5, Timer B5                                   */
#define TMRB4        0x06  /* Vector 6, Timer B4                                   */
#define U1BUS        0x06  /* Vector 6, Bus collision detection UART1              */
#define TMRB3        0x07  /* Vector 7, Timer B3                                   */
#define U0BUS        0x07  /* Vector 7, Bus collision detection UART0              */
#define SIO4         0x08  /* Vector 8, Serial I/O 4                               */
#define INT5         0x08  /* Vector 8, External source                            */
#define SIO3         0x09  /* Vector 9, Serial I/O 3                               */
#define INT4         0x09  /* Vector 9, External                                   */
#define U2BUS        0x0A  /* Vector 10, Bus collision detection UART2             */
#define DMA0         0x0B  /* Vector 11, DMA0                                      */
#define DMA1         0x0C  /* Vector 12, DMA1                                      */
#define KEY          0x0D  /* Vector 13, Key input                                 */
#define AD           0x0E  /* Vector 14, A-D converter                             */
#define UART2_TX     0x0F  /* Vector 15, UART2 transmit                            */
#define UART2_RX     0x10  /* Vector 16, UART2 receive                             */
#define UART0_TX     0x11  /* Vector 17, UART0 transmit                            */
#define UART0_RX     0x12  /* Vector 18, UART0 receive                             */
#define UART1_TX     0x13  /* Vector 19, UART1 transmit                            */
#define UART1_RX     0x14  /* Vector 20, UART1 receive                             */
#define TMRA0        0x15  /* Vector 21, Timer A0                                  */
#define TMRA1        0x16  /* Vector 22, Timer A1                                  */
#define TMRA2        0x17  /* Vector 23, Timer A2                                  */
#define TMRA3        0x18  /* Vector 24, Timer A3                                  */
#define TMRA4        0x19  /* Vector 25, Timer A4                                  */
#define TMRB0        0x1A  /* Vector 26, Timer B0                                  */
#define TMRB1        0x1B  /* Vector 27, Timer B1                                  */
#define TMRB2        0x1C  /* Vector 28, Timer B2                                  */
#define INT0         0x1D  /* Vector 29, External source                           */
#define INT1         0x1E  /* Vector 30, External source                           */
#define INT2         0x1F  /* Vector 31, External source                           */



#endif


