// serial.c

#include <string.h>
#include "delay_timer.h"
#include "serial.h"
#include "iom16c62p.h"

extern volatile unsigned char TimerChannelDelayStatus[];

// **************************
// *                        *
// *       InitSCI          *
// *                        *
// **************************

void InitSci ( void )
{
	volatile unsigned long bit_delay;
	
	// serial port initialisation
	//
			
	// transmit/receive mode register
										//	serial I/O mode select
	U0MR_bit.SMD0_U0MR = 1;		//	SMD2	SMD1	SMD0
	U0MR_bit.SMD1_U0MR = 0;		//	0		0		0		- serial I/O disabled
	U0MR_bit.SMD2_U0MR = 1;		//	0		0		1		- clock synchronouse serial I/O mode
								//	0		1		0		- I2C mode
								//	0		1		1		- DO NOT SET
								//	1		0		0		- UART mode transfer data 7 bits long	
								//	1		0		1		- UART mode transfer data 8 bits long
								//	1		1		0		- UART mode transfer data 9 bits long
								//	1		1		1		- DO NOT SET
	
								//	internal/external clock select bit
	U0MR_bit.CKDIR_U0MR = 0;	//	0 - internal clock
								//	1 - external clock (set port bit to input)
	
								// 	stop bit length select bit
	U0MR_bit.STPS_U0MR = 0;		//	0 - one stop bit
								//	1 - two stop bits
								
								//	odd/even priority select bit
	U0MR_bit.PRY_U0MR = 0;		//	0 - odd parity (active when PRYE = 1)
								//	1 - even parity (active when PRYE = 1)
								
								//	priority enable bit
	U0MR_bit.PRYE_U0MR = 0;		//	0 - parity disabled
								//	1 - parity enabled
								
								//	TxD/RxD I/O polarity reverse bit
	U0MR_bit.IOPOL_U0MR = 0;	//	0 - no reveers
								//	1 - reverse

	// transmit/receive control register
								//	BRG count source select
	U0C0_bit.CLK0_U0C0 = 0;		//	CLK1	CLK0
	U0C0_bit.CLK1_U0C0 = 0;		//	0		0				- f1SIO or f2SIO selected
								//	0		1				- f8SIO selected
								//	1		0				- f32SIO selected
								//	1		1				- DO NOT SET
				
								//	CTS/RTS function select bit
	U0C0_bit.CRS_U0C0 = 0;		//	0 - CTS function selected
								//	1 - RTS function selected
									//	CTS/RTS disable bit
	U0C0_bit.CRD_U0C0 = 0;		//	0 - CTS/RTS function enabled
								//	1 - CTS/RTS function disabled
								
								//	data output select bit
	U0C0_bit.NCH_U0C0 = 0;		//	0 - TxD/SDA and SCL pins CMOS ouput
								//	1 - TxD/SDA and SCL pins N-channel open drain outputs
								
								//	CLK polarity select bit
	U0C0_bit.CKPOL_U0C0 = 0;	//	0 - Tx data output on falling edge of transfer clock and Rx data receive on rising edge
								//	1 - Tx data output on rising edge of transfer clock and Rx data receive on falling edge
								
								//	transfer format select bit
	U0C0_bit.UFORM_U0C0 = 0;	//	0 - LSB first
								//	1 - MSB first
									
	U0BRG = BAUD(115200L);		// set baud rate
	
	// special mode register
	U0SMR = 0;					//	not used in UART mode
	
	// special mode register 2
	U0SMR2 = 0;					//	not used in UART mode
	
	// special mode register 3
	U0SMR3 = 0;					//	not used in UART mode
	
	// special mode register 4
	U0SMR4 = 0;					//	not used in UART mode
	
	//	transmit/receive control register
								// 	transmit enable bit
	U0C1_bit.TE_U0C1 = 1;		//	0 - transmission disabled
								//	1 - transmission enabled
	
								// 	receive enable bit
	U0C1_bit.RE_U0C1 = 1;		//	0 - reception disabled
								//	1 - reception enabled
	
	// make P6.3 an output
	PD6_bit.PD6_3 = 1;
}

// **************************
// *                        *
// *    ClearSCITxFlag      *
// *                        *
// **************************

static void ClearSCITxFlag( void )
{
		// cleared by writing to the U0TB lower byte
}

// **************************
// *                        *
// *      RxByteWaiting     *
// *                        *
// **************************

static unsigned char RxByteWaiting ( void )
{
	//
	// returns 1 - if the byte is waiting
	// returns 0 - if no byte is waiting
	//
	
	unsigned char tmp;
	
	if( U0C1_bit.RI_U0C1 == 0 )
	{
		tmp = 0;
	}
	else
	{
		tmp = 1;
	}

	return tmp;
}

// **************************
// *                        *
// *     TxByteEmpty        *
// *                        *
// **************************

static unsigned char TxByteEmpty ( void )
{
	//
	// returns 1 - if the transmit register is empty
	// returns 0 - if the transmit register is not empty
	//
	
	unsigned char tmp;
	
	if( U0C1_bit.TI_U0C1 == 0 )
	{
		tmp = 0;
	}
	else
	{
		tmp = 1;
	}
	
	return tmp;
}

// **************************
// *                        *
// *      TxByteLoad        *
// *                        *
// **************************

static void TxByteLoad( unsigned char b )
{
		U0TBL = b;
}

// **************************
// *                        *
// *   EnableTxInterrupt    *
// *                        *
// **************************

void EnableTxInterrupt( void )
{
	U0C1_bit.TI_U0C1 = 1;
}

// **************************
// *                        *
// *   DisableTxInterrupt    *
// *                        *
// **************************

void DisableTxInterrupt( void )
{
	U0C1_bit.TI_U0C1 = 0;
}

// **************************
// *                        *
// *   EnableTxEndInterrupt    *
// *                        *
// **************************

void EnableTxEndInterrupt( void )
{
}

// **************************
// *                        *
// *   DisableTxInterrupt    *
// *                        *
// **************************

void DisableTxEndInterrupt( void )
{
}

// **************************
// *                        *
// *   Interrupt Service    *
// *        Routines        *
// *                        *
// **************************
//
// **************************
// *                        *
// *       Channel 0        *
// *                        *
// **************************



// **************************
// *                        *
// *   User API functions   *
// *                        *
// **************************

// **************************
// *                        *
// *       SendByte         *
// *                        *
// **************************

void SendByte ( unsigned char b )
{
	while( TxByteEmpty() == 0 );
	TxByteLoad( b );
	ClearSCITxFlag();
}

// **************************
// *                        *
// *       SendString       *
// *                        *
// **************************

void SendString ( char* str )
{
	// sends string until NUL terminator is reached
	
	unsigned short us;

	us = 0;
	while ( str[us] != 0 )
	{
		SendByte ( (unsigned char) str[us] );
		us++;
	}
}

// **************************
// *                        *
// *       GetByte          *
// *                        *
// **************************


unsigned short GetByte ( unsigned long timeout )
{
	//	timeout = time in ms for which to timeout the data reception
	//
	//	returns a 16-bit value
	//	upper (msb) byte contains status info
	//	lower (lsb) byte contains the data received from the SCI channel
	//
	//	status:
	//	OK
	//	ERROR
	//	TIMEOUT
	//
	
	union union_c2s c2s;	
	unsigned long tick_count;
	
	tick_count = timeout / MS_PER_TIMER_COMPARE_MATCH;
	
	StartDelayTimer();
	
	// wait for a byte to arrive
	while ( ( RxByteWaiting() == 0 ) && (tick_count) )
	{
		if ( GetDelayTimerStatus() )
		{
			StopDelayTimer();
			if ( --tick_count )
			{
				StartDelayTimer();
			}
		}
	}
	
	if ( RxByteWaiting() == 1 )
	{
		// read error flags and data
		c2s.us = U0RB;
		
		// check for errors
		if( c2s.uc[1] & 0x80 )
		{
			// Rx error
			//
			// check for parity error
			if( c2s.uc[1] & 0x40 )
			{
				// parity error
			}
			// check for framing error
			if( c2s.uc[1] & 0x20 )
			{
				// framing error
			}
			// check for overrun error
			if( c2s.uc[1] & 0x10 )
			{
				// overrun error
				// clearing the overrun error flag is a special case
				//
				// clear Tx enable
				U0C1_bit.RE_U0C1 = 0;
				// set Tx enable
				U0C1_bit.RE_U0C1 = 1;
			}
			
			c2s.uc[ 0 ] = ERROR;
		}
		else
		{
			// no Rx error
			c2s.uc[ 1 ] = c2s.uc[ 0 ];
			c2s.uc[ 0 ] = OK;
		}		
	}
	else
	{
		c2s.uc[0] = TIMEOUT;
	}
	
	return (c2s.us);
}

// **************************
// *                        *
// *       PurgeComms       *
// *                        *
// **************************

void PurgeComms ( unsigned long timeout )
{
	union union_c2s c2s;
	
	do {
		c2s.us = GetByte( timeout );
	} while( (c2s.uc[0] != TIMEOUT) && (c2s.uc[0] != ERROR) );

}

// **************************
// *                        *
// *       SendLFCR         *
// *                        *
// **************************

void SendLFCR( void )
{
	SendByte( LINEFEED );
	SendByte( CARRIAGE_RETURN );
}
