// delay_timer.c

#include "delay_timer.h"
#include "iom16c62p.h"

static unsigned char DelayTimerUnderFlowFlag = 0;

void InitDelayTimer (void)
{
	// stop the timer channel
	TABSR_bit.TA0S = 0;						//	0 - stops counting
											//	1 - starts counting
	
	// Timer A mode register
											//	operation mode select bits
											//	TM0D1	TM0D0
	TA0MR_bit.TMOD0_TA0MR = 0;				//	0		0			- timer mode
	TA0MR_bit.TMOD1_TA0MR = 0;				//	0		1			- event counter mode
											//	1		0			- one-shot timer mode
											//	1		1			- pwm mode
											
											//	pulse output function bit
	TA0MR_bit.MR0_TA0MR = 0;				// 	0 - pulse not output
											//	1 - pulse output
	
											//	gate function select bits
											//	MR2	MR1	MR0
	TA0MR_bit.MR1_TA0MR = 0;				//	0	0	0			- gate function not available
											//	0	0	1			- 
											//	0	1	0
											//	0	1	1
											//	1	0	0
											//	1	0	1
											//	1	1	0
											//	1	1	1
											
	TA0MR_bit.MR2_TA0MR = 0;				// "
	TA0MR_bit.MR3_TA0MR = 0;				// must be '0' in timer mode
	TA0MR_bit.TCK0_TA0MR = 0;				// clock = f32
	TA0MR_bit.TCK1_TA0MR = 1;				// "
	
	// timer counts down
	UDF_bit.TA0UD = 0;
	
	// interrupt priority level
	TA0IC = 5;
}

void StartDelayTimer (void)
{
	DelayTimerUnderFlowFlag = 0;
	TA0 = ONE_MSEC - 1;						// set initial count value
	TABSR_bit.TA0S = 1;		 				// start timer
}

void StopDelayTimer (void)
{
	TABSR_bit.TA0S = 0;						// stop timer
}

unsigned char GetDelayTimerStatus (void)
{
	if ( DelayTimerUnderFlowFlag == 1 )
	{
		return (1);
	}			   
	else
	{
		return (0);
	}
}

#pragma vector = 21
__interrupt void TimerA0Interrupt( void )
{
   DelayTimerUnderFlowFlag = 1;
   StopDelayTimer();
}
